*************************************************************;
/*    WiilSU2014_Analysis.sas

Directory:  D:\WiilSU_2014\WiilSU Analysis
            
Author:  Deanna Naomi Schreiber-Gregory

Created:  February 26th, 2014

Revised:  March 7th, 2014

Purpose/Abstract:  This Program performs a factor analysis of 
				   numeric-converted variables for the YRBSS
				   project.

				   Insert conversions directly into renaming of
				   variables: ie, AlcoholLife1=q31*1

Input data file ----------------------------------------------
	YRBS1991.dat
	YRBS1993.dat
	YRBS1995.dat
	YRBS1997.dat
	YRBS1999.dat
	YRBS2001.dat
	YRBS2003.dat
	YRBS2005.dat
	YRBS2007.dat
	YRBS2009.dat
	YRBS2011.dat

Created Variables --------------------------------------------
   Too Many: concatenated variables based on excel File
   D:\WiilSU_2014\WiilSU Analysis\Application\Survey Questions.xlsx

Data Source:  CDC
*/
**************************************************************;

/* Tell SAS where to find the data files and formats */

OPTIONS NODATE NONUMBER NOCENTER SKIP=0;
libname mydata 'D:\WiilSU_2014\WiilSU Analysis';			/* Tells SAS where the data is */
libname library 'D:\WiilSU_2014\WiilSU Analysis';		/* Tells SAS where the formats are */

/* ODS RTF; */
title1 "YRBSS Analysis - WiilSU 2014";

ods graphics on;

/* Format and input data from YRBS 1991 */

data YRBS1991;													/* Create SAS dataset YRBS1991 */
	set mydata.YRBS1991;										/* The SET statement reads data from an existing SAS dataset */
	
	year=1991;
	AlcoholLife1=q33*1; AlcoholDay2=q34*1; AlcoholBinge4=q35*1;														/* Alcohol */
	DemoAge1=q1*1; DemoSex2=q2*1; DemoEth3=q4*1; 																		/* Demotgraphics */
	DrugsMarLife1=q37*1; DrugsMarDay2=q38*1; DrugsCocaLife1=q40*1; DrugsCocaDay2=q41*1; DrugsSteroLife1=q44*1; 			/* Drugs */
	DrugsComboLife1=q43*1;
	EduRank2=q5*1; ExerHardActive1=q68*1; ExerStrength4=q70*1; ExerStretch5=q69*1; 										/* Exercise */
	MoodConsiderS2=q19*1; MoodPlanS3=Q20*1; MoodAttemptS4=q21*1; MoodSeriousS5=q22*1;									/* Mood */
	SexHist2=q48*1; SexAge3=q49*1; SexNumLife4=q50*1; SexNumMonth4=q51*1; SexSub5=q52*1; SexProtect7=q54*1; 				/* Sexuality */
	SexPregnant8=q55*1; SexSTD9=q56*1;		
	TobacTry1=q23*1; TobacDaily2=q26*1; TobacDays4=q28*1; TobacAmount5=q29*1; 											/* Tobacco */
	VehicleHelmet1=q8*1; VehicleSelfSB2=q6*1; VehicleOtherD3=q11*1; VehicleSelfD3=q12*1;								/* Vehicle */
	ViolMultWeap1=q14*1; ViolFight3=q16*1; ViolInjury3=q18*1; ViolWhom4=q17*1;											/* Violence */
	WeightThink1=q57*1; WeightTry1=q58*1;																			/* Weight */

	if q59=1 or q59=5 then WeightDietExer02='2';																	/* Adjusted */
	else if q59=2 or q59=3 or q59=4 then WeightDietExer02='1';
	else WeightDietExer02=' ';

		WeightDietExer2=WeightDietExer02*1; drop WeightDietExer02;

	if q60=1 or q60=5 then WeightPurge02='2';
	else if q60=2 or q60=3 or q60=4 then WeightPurge02='1';
	else WeightPurge02=' ';

		WeightPurge2=WeightPurge02*1; drop WeightPurge02;

	if q31=1 then TobacChew07='2';
	else if q31=2 or q31=3 or q31=4 then TobacChew07='1';
	else TobacChew07=' ';

		TobacChew7=TobacChew07*1; drop TobacChew07;

	if q30=2 then TobacQuit03='1';
	else if q30=3 then TobacQuit03='2';
	else TobacQuit03=' ';

		TobacQuit3=TobacQuit03*1; drop TobacQuit03;

	if q74=1 and q75=1 then ExerTeam06='1';
	else if (q74=1 and q75=2) or (q74=2 and q75=1) then ExerTeam06='2';
	else if (q74=1 and q75=3) or (q74=3 and q75=1) or (q74=2 and q75=2) then ExerTeam06='3';
	else if (q74=2 and q75=3) or (q74=3 and q75=2) or (q74=3 and q75=3) or q74=4 or q75=4 then ExerTeam06='4';
	else ExerTeam06=' ';

		ExerTeam6=ExerTeam06*1; drop ExerTeam06;

	drop q1-q98 qn1-qn98 qnfrcig qnfrvg qnrovwgt qnovwgt qndlype qnanytob qnminpa qnnopa qnasatck bmipct ethorig raceorig qndepo
		 qndepopl qndual qnfrvg2 qnfruit qnveg qnpa0day qnpa7day qnowt qnobese metrost qnstore qnabstsx qnrespsx qntencig
		 q4orig;

run;

/* Format and input data from YRBS 1993 */

data YRBS1993;													/* Create SAS dataset YRBS1993 */
	set mydata.YRBS1993;										/* The SET statement reads data from an existing SAS dataset */

	year=1993;
	AlcoholLife1=q39*1; AlcoholDay2=q40*1; AlcoholBinge4=q41*1; 														/* Alcohol */
	DemoAge1=q1*1; DemoSex2=q2*1; DemoEth3=q4*1;																		/* Demographics */
	DrugsMarLife1=q44*1; DrugsMarDay2=q45*1; DrugsMarDaySP3=q46*1; DrugsCocaLife1=q48*1; DrugsCocaDay2=q49*1; 			/* Drugs */
	DrugsSteroLife1=q52*1; DrugsInjectLife1=q53*1; DrugsComboLife1=q51*1;									
	EduRank2=q5*1; EduMom4=q86*1; EduDad5=q87*1;																		/* Education */
	ExerHardActive1=q77*1; ExerStrength4=q79*1; ExerStretch5=q78*1; 													/* Exercise */
	MoodConsiderS2=q24*1; MoodPlanS3=q25*1; MoodAttemptS4=q26*1; MoodSeriousS5=q27*1;									/* Mood */
	SexHist2=q57*1; SexAge3=q58*1; SexNumLife4=q59*1; SexNumMonth4=q60*1; SexSub5=q61*1; SexProtect7=q63*1; 				/* Sexuality */
	SexPregnant8=q64*1; SexSTD9=q65*1;
	TobacTry1=q28*1; TobacDaily2=q30*1; TobacDays4=q32*1; TobacDaysSP4=q34*1; TobacAmount5=q33*1; 						/* Tobacco */
	VehicleHelmet1=q8*1; VehicleSelfSB2=q6*1; VehicleOtherD3=q11*1; VehicleSelfD3=q12*1;								/* Vehicle */
	ViolMultWeap1=q13*1; ViolMultWeapSP1=q15*1; ViolGun1=q14*1; ViolUnsafe2=q16*1; ViolThreatSP2=q17*1; 					/* Violence */
	ViolDamageSP2=q18*1; ViolFight3=q19*1; ViolFightSP3=q22*1; ViolInjury3=q21*1; ViolWhom4=q20*1;
	WeightThink1=q66*1; WeightTry1=q67*1;																			/* Weight */

	if q68=1 or q68=5 then WeightDietExer02='2';																	/* Adjusted */
	else if q68=2 or q68=3 or q68=4 then WeightDietExer02='1';
	else WeightDietExer02=' ';

		WeightDietExer2=WeightDietExer02*1; drop WeightDietExer02;

	if q69=1 or q69=5 then WeightPurge02='2';
	else if q69=2 or q69=3 or q69=4 then WeightPurge02='1';
	else WeightPurge02=' ';

		WeightPurge2=WeightPurge02*1; drop WeightPurge02;

	if q37=1 then TobacChewSP08='2';
	else if q37=2 or q37=3 or q37=4 then TobacChewSP08='1';
	else TobacChewSP08=' ';

		TobacChewSP8=TobacChewSP08*1; drop TobacChewSP08;

	if q36=1 then TobacChew07='2';
	else if q36=2 or q36=3 or q36=4 then TobacChew07='1';
	else TobacChew07=' ';

		TobacChew7=TobacChew07*1; drop TobacChew07;

	if q35=2 then TobacQuit03='1';
	else if q35=3 then TobacQuit03='2';
	else TobacQuit03=' ';

		TobacQuit3=TobacQuit03*1; drop TobacQuit03;

	if q83=1 and q84=1 then ExerTeam06='1';
	else if (q83=1 and q84=2) or (q83=2 and q84=1) then ExerTeam06='2';
	else if (q83=1 and q84=3) or (q83=3 and q84=1) or (q83=2 and q84=2) then ExerTeam06='3';
	else if (q83=2 and q84=3) or (q83=3 and q84=2) or (q83=3 and q84=3) or q83=4 or q84=4 then ExerTeam06='4';
	else ExerTeam06=' ';

		ExerTeam6=ExerTeam06*1; drop ExerTeam06;

	if q42=1 then AlcoholDaySP03='1';
	else if q42=2 or q42=3 then AlcoholDaySP03='2';
	else if q42=4 then AlcoholDaySP03='3';
	else if q42=5 then AlcoholDaySP03='4';
	else if q42=6 then AlcoholDaySP03='5';
	else if q42=7 then AlcoholDaySP03='6';
	else AlcoholDaySP03=' ';

		AlcoholDaySP3=AlcoholDaySP03*1; drop AlcoholDaySP03;

	drop q1-q98 qn1-qn98 qnfrcig qnfrvg qnrovwgt qnovwgt qndlype qnanytob qnminpa qnnopa qnasatck bmipct ethorig raceorig qndepo
		 qndepopl qndual qnfrvg2 qnfruit qnveg qnpa0day qnpa7day qnowt qnobese metrost qnstore qnabstsx qnrespsx qntencig
		 q4orig;

run;

/* Format and input data from YRBS 1995 */

data YRBS1995;													/* Create SAS dataset YRBS1995 */
	set mydata.YRBS1995;										/* The SET statement reads data from an existing SAS dataset */

	year=1995;
	AlcoholLife1=q37*1; AlcoholDay2=q38*1; AlcoholBinge4=q39*1; 														/* Alcohol */
	DemoAge1=q1*1; DemoSex2=q2*1; DemoEth3=q4*1; 																		/* Demographics */
	DrugsMarLife1=q42*1; DrugsMarDay2=q43*1; DrugsMarDaySP3=q44*1; DrugsCocaLife1=q46*1; 								/* Drugs */
	DrugsCocaDay2=q47*1; DrugsInhaLife1=q49*1; DrugsSteroLife1=q50*1; DrugsComboLife1=q51*1;
	EduMom4=q87*1; EduDad5=q88*1; 																					/* Education */
	ExerHardActive1=q77*1; ExerSoftActive1=q80*1; ExerStrength4=q79*1; ExerStretch5=q78*1; 								/* Exercise */
	MoodConsiderS2=q22*1; MoodPlanS3=q23*1; MoodAttemptS4=q24*1; MoodSeriousS5=q25*1;									/* Mood */
	SexHist2=q56*1; SexAge3=q57*1; SexNumLife4=q58*1; SexNumMonth4=q59*1; SexSub5=q60*1;									/* Sexuality */
	SexProtect7=q62*1; SexPregnant8=q63*1;
	TobacTry1=q26*1; TobacDaily2=q85*1; TobacDays4=q28*1; TobacDaysSP4=q32*1; TobacAmount5=q29*1; 						/* Tobacco */
	VehicleHelmet1=q7*1; VehicleSelfSB2=q5*1; VehicleOtherD3=q10*1; VehicleSelfD3=q11*1;								/* Vehicle */
	ViolMultWeap1=q12*1; ViolMultWeapSP1=q14*1; ViolGun1=q13*1; ViolUnsafe2=q15*1; ViolThreatSP2=q16*1;					/* Violence */
	ViolDamageSP2=q17*1; ViolFight3=q18*1; ViolFightSP3=q20*1; ViolInjury3=q19*1; ViolWhom4=q21*1;
	WeightThink1=q64*1; WeightTry1=q65*1; WeightSupp2=q69*1; WeightPurge2=q68*1;										/* Weight */

	if q30=1 then TobacGet06='1';
	else if q30=2 then TobacGet06='2';
	else if q30=3 then TobacGet06='3';
	else if q30=4 then TobacGet06='4';
	else if q30=5 then TobacGet06='5';
	else if q30=6 then TobacGet06='6';
	else if q30=7 then TobacGet06='7';
	else TobacGet06=' ';

		TobacGet6=TobacGet06*1; drop TobacGet06;

	if q67=1 or q66=1 then WeightDietExer02='1';																	/* Adjusted */
	else if q67=2 and q66=2 then WeightDietExer02='2';
	else WeightDietExer02=' ';

		WeightDietExer2=WeightDietExer02*1; drop WeightDietExer02;

	if q35=1 then TobacChewSP08='2';
	else if q35=2 or q35=3 or q35=4 or q35=5 or q35=6 or q35=7 then TobacChewSP08='1';
	else TobacChewSP08=' ';

		TobacChewSP8=TobacChewSP08*1; drop TobacChewSP08;

	if q34=1 then TobacChew07='2';
	else if q34=2 or q34=3 or q34=4 or q34=5 or q34=6 or q34=7 then TobacChew07='1';
	else TobacChew07=' ';

		TobacChew7=TobacChew07*1; drop TobacChew07;

	if q33=2 then TobacQuit03='1';
	else if q33=3 then TobacQuit03='2';
	else TobacQuit03=' ';

		TobacQuit3=TobacQuit03*1; drop TobacQuit03;

	if q83=1 and q84=1 then ExerTeam06='1';
	else if (q83=1 and q84=2) or (q83=2 and q84=1) then ExerTeam06='2';
	else if (q83=1 and q84=3) or (q83=3 and q84=1) or (q83=2 and q84=2) then ExerTeam06='3';
	else if (q83=2 and q84=3) or (q83=3 and q84=2) or (q83=3 and q84=3) or q83=4 or q84=4 then ExerTeam06='4';
	else ExerTeam06=' ';

		ExerTeam6=ExerTeam06*1; drop ExerTeam06;

	if q52=1 then DrugsInjectLife01='2';
	else if q52=2 or q52=3 then DrugsInjectLife01='1';
	else DrugsInjectLife01=' ';

		DrugsInjectLife1=DrugsInjectLife01*1; drop DrugsInjectLife01;

	if q40=1 then AlcoholDaySP03='1';
	else if q40=2 or q40=3 then AlcoholDaySP03='2';
	else if q40=4 then AlcoholDaySP03='3';
	else if q40=5 then AlcoholDaySP03='4';
	else if q40=6 then AlcoholDaySP03='5';
	else if q40=7 then AlcoholDaySP03='6';
	else AlcoholDaySP03=' ';

		AlcoholDaySP3=AlcoholDaySP03*1; drop AlcoholDaySP03;

	drop q1-q98 qn1-qn98 qnfrcig qnfrvg qnrovwgt qnovwgt qndlype qnanytob qnminpa qnnopa qnasatck bmipct ethorig raceorig qndepo
		 qndepopl qndual qnfrvg2 qnfruit qnveg qnpa0day qnpa7day qnowt qnobese metrost qnstore qnabstsx qnrespsx qntencig
		 q4orig;

run;

/* Format and input data from YRBS 1997 */

data YRBS1997;													/* Create SAS dataset YRBS1997 */
	set mydata.YRBS1997;										/* The SET statement reads data from an existing SAS dataset */

	year=1997;
	AlcoholLife1=q37*1; AlcoholDay2=q38*1; AlcoholBinge4=q39*1; 														/* Alcohol */
	DemoAge1=q1*1; DemoSex2=q2*1; DemoEth3=q4*1; 																		/* Demographics */
	DrugsMarLife1=q42*1; DrugsMarDay2=q43*1; DrugsMarDaySP3=q44*1; DrugsCocaLife1=q46*1; 								/* Drugs */
	DrugsCocaDay2=q47*1; DrugsInhaLife1=q49*1; DrugsSteroLife1=q50*1; DrugsComboLife1=q51*1;
	EduMom4=q88*1; EduDad5=q89*1;																					/* Education */
	ExerHardActive1=q77*1; ExerSoftActive1=q80*1; ExerStrength4=q79*1; ExerStretch5=q78*1; 								/* Exercise */
	MoodConsiderS2=q22*1; MoodPlanS3=q23*1; MoodAttemptS4=q24*1; MoodSeriousS5=q25*1;									/* Mood */
	SexHist2=q56*1; SexAge3=q57*1; SexNumLife4=q58*1; SexNumMonth4=q59*1; 												/* Sexuality */
	SexSub5=q60*1; SexProtect7=q62*1; SexPregnant8=q63*1;
	TobacTry1=q26*1; TobacDaily2=q85*1; TobacDays4=q28*1; TobacDaysSP4=q32*1; TobacAmount5=q29*1;							/* Tobacco */
	VehicleHelmet1=q7*1; VehicleSelfSB2=q5*1; VehicleOtherD3=q10*1; VehicleSelfD3=q11*1;								/* Vehicle */
	ViolMultWeap1=q12*1; ViolMultWeapSP1=q14*1; ViolGun1=q13*1; ViolUnsafe2=q15*1;										/* Violence */
	ViolThreatSP2=q16*1; ViolDamageSP2=q17*1; ViolFight3=q18*1; ViolFightSP3=q20*1;
	ViolInjury3=q19*1;
	WeightThink1=q64*1; WeightTry1=q65*1; WeightSupp2=q69*1; WeightPurge2=q68*1;										/* Weight */

	if q30=1 then TobacGet06='1';
	else if q30=2 then TobacGet06='2';
	else if q30=3 then TobacGet06='3';
	else if q30=4 then TobacGet06='4';
	else if q30=5 then TobacGet06='5';
	else if q30=6 then TobacGet06='6';
	else if q30=7 then TobacGet06='7';
	else TobacGet06=' ';

		TobacGet6=TobacGet06*1; drop TobacGet06;

	if q67=1 or q66=1 then WeightDietExer02='1';																	/* Adjusted */
	else if q67=2 and q66=2 then WeightDietExer02='2';
	else WeightDietExer02=' ';

		WeightDietExer2=WeightDietExer02*1; drop WeightDietExer02;

	if q86=1 then TobacCigar09='2';
	else if q86=2 or q86=3 or q86=4 or q86=5 or q86=6 or q86=7 then TobacCigar09='1';
	else TobacCigar09=' ';

		TobacCigar9=TobacCigar09*1; drop TobacCigar09;

	if q35=1 then TobacChewSP08='2';
	else if q35=2 or q35=3 or q35=4 or q35=5 or q35=6 or q35=7 then TobacChewSP08='1';
	else TobacChewSP08=' ';

		TobacChewSP8=TobacChewSP08*1; drop TobacChewSP08;

	if q34=1 then TobacChew07='2';
	else if q34=2 or q34=3 or q34=4 or q34=5 or q34=6 or q34=7 then TobacChew07='1';
	else TobacChew07=' ';

		TobacChew7=TobacChew07*1; drop TobacChew07;

	if q33=2 then TobacQuit03='1';
	else if q33=3 then TobacQuit03='2';
	else TobacQuit03=' ';

		TobacQuit3=TobacQuit03*1; drop TobacQuit03;

	if q62=2 then SexProtect07='2';
	else if q62=3 or q62=4 or q62=5 or q62=6 then SexProtect07='1';
	else if q62=7 then SexProtect07='3';
	else SexProtect07=' ';

		SexProtect7=SexProtect07*1; drop SexProtect07;

	if q83=1 and q84=1 then ExerTeam06='1';
	else if (q83=1 and q84=2) or (q83=2 and q84=1) then ExerTeam06='2';
	else if (q83=1 and q84=3) or (q83=3 and q84=1) or (q83=2 and q84=2) then ExerTeam06='3';
	else if (q83=2 and q84=3) or (q83=3 and q84=2) or (q83=3 and q84=3) or q83=4 or q84=4 then ExerTeam06='4';
	else ExerTeam06=' ';

		ExerTeam6=ExerTeam06*1; drop ExerTeam06;

	if q52=1 then DrugsInjectLife01='2';
	else if q52=2 or q52=3 then DrugsInjectLife01='1';
	else DrugsInjectLife01=' ';

		DrugsInjectLife1=DrugsInjectLife01*1; drop DrugsInjectLife01;

	if q40=1 then AlcoholDaySP03='1';
	else if q40=2 or q40=3 then AlcoholDaySP03='2';
	else if q40=4 then AlcoholDaySP03='3';
	else if q40=5 then AlcoholDaySP03='4';
	else if q40=6 then AlcoholDaySP03='5';
	else if q40=7 then AlcoholDaySP03='6';
	else AlcoholDaySP03=' ';

		AlcoholDaySP3=AlcoholDaySP03*1; drop AlcoholDaySP03;

	drop q1-q98 qn1-qn98 qnfrcig qnfrvg qnrovwgt qnovwgt qndlype qnanytob qnminpa qnnopa qnasatck bmipct ethorig raceorig qndepo
		 qndepopl qndual qnfrvg2 qnfruit qnveg qnpa0day qnpa7day qnowt qnobese metrost qnstore qnabstsx qnrespsx qntencig
		 q4orig;

run;

/* Format and input data from YRBS 1999 */

data YRBS1999;													/* Create SAS dataset YRBS1999 */
	set mydata.YRBS1999;										/* The SET statement reads data from an existing SAS dataset */

	year=1999;
	AlcoholLife1=q39*1; AlcoholDay2=q41*1; AlcoholBinge4=q42*1; 															/* Alcohol */
	DemoAge1=q1*1; DemoSex2=q2*1; 																						/* Demographics */
	DrugsMarLife1=q44*1; DrugsMarDay2=q46*1; DrugsMarDaySP3=q47*1; DrugsCocaLife1=q48*1;									/* Drugs */
	DrugsCocaDay2=q49*1; DrugsInhaLife1=q50*1; DrugsInhaDay2=q51*1; DrugsHeroLife1=q52*1;
	DrugsMethLife1=q53*1; DrugsSteroLife1=q54*1;
	ExerHardActive1=q79*1; ExerSoftActive1=q80*1; ExerStrength4=q81*1; ExerTeam6=q85*1; 									/* Exercise */
	HealthDoctor1=q89*1; HealthDentist2=q91*1; 																			/* Health */
	MoodDep1=q22*1; MoodConsiderS2=q23*1; MoodPlanS3=q24*1; MoodAttemptS4=q25*1; MoodSeriousS5=q26*1;							/* Mood */
	SexForce1=q21*1; SexHist2=q57*1; SexAge3=q58*1; SexNumLife4=q59*1; SexNumMonth4=q60*1; SexSub5=q61*1;						/* Sexuality */
	SexPregnant8=q64*1; 
	TobacTry1=q27*1; TobacDaily2=q34*1; TobacDays4=q29*1; TobacDaysSP4=q33*1; TobacAmount5=q30*1;								/* Tobacco */
	TobacQuit3=q35*1; 
	VehicleHelmet1=q7*1; VehicleSelfSB2=q9*1; VehicleOtherD3=q10*1; VehicleSelfD3=q11*1;									/* Vehicle */
	ViolMultWeap1=q12*1; ViolMultWeapSP1=q14*1; ViolGun1=q13*1; ViolUnsafe2=q15*1; ViolThreatSP2=q16*1;						/* Violence */
	ViolFight3=q17*1; ViolFightSP3=q19*1; ViolInjury3=q18*1; ViolSigOth4=q20*1;
	WeightThink1=q65*1; WeightTry1=q66*1; WeightFast2=q69*1; WeightSupp2=q70*1; WeightPurge2=q71*1;							/* Weight */

	if q31=1 then TobacGet06='1';
	else if q31=2 then TobacGet06='2';
	else if q31=3 then TobacGet06='3';
	else if q31=4 then TobacGet06='4';
	else if q31=5 then TobacGet06='5';
	else if q31=6 then TobacGet06='6';
	else if q31=7 then TobacGet06='7';
	else TobacGet06=' ';

		TobacGet6=TobacGet06*1; drop TobacGet06;

	if q67=1 or q68=1 then WeightDietExer02='1';																		/* Adjusted */
	else if q67=2 and q68=2 then WeightDietExer02='2';
	else WeightDietExer02=' ';

		WeightDietExer2=WeightDietExer02*1; drop WeightDietExer02;

	if q38=1 then TobacCigar09='2';
	else if q38=2 or q38=3 or q38=4 or q38=5 or q38=6 or q38=7 then TobacCigar09='1';
	else TobacCigar09=' ';

		TobacCigar9=TobacCigar09*1; drop TobacCigar09;

	if q37=1 then TobacChewSP08='2';
	else if q37=2 or q37=3 or q37=4 or q37=5 or q37=6 or q37=7 then TobacChewSP08='1';
	else TobacChewSP08=' ';

		TobacChewSP8=TobacChewSP08*1; drop TobacChewSP08;

	if q36=1 then TobacChew07='2';
	else if q36=2 or q36=3 or q36=4 or q36=5 or q36=6 or q36=7 then TobacChew07='1';
	else TobacChew07=' ';

		TobacChew7=TobacChew07*1; drop TobacChew07;

	if q63=2 then SexProtect07='2';
	else if q63=3 or q63=4 or q63=5 or q63=6 or q63=7 then SexProtect07='1';
	else if q63=8 then SexProtect07='3';
	else SexProtect07=' ';

		SexProtect7=SexProtect07*1; drop SexProtect07;

	if q86=1 then ExerInjury07='2';
	else if q86=2 or q86=3 or q86=4 or q86=5 or q86=6 then ExerInjury07='1';
	else ExerInjury07=' ';

		ExerInjury7=ExerInjury07*1; drop ExerInjury07;

	if q55=1 then DrugsInjectLife01='2';
	else if q55=2 or q55=3 then DrugsInjectLife01='1';
	else DrugsInjectLife01=' ';

		DrugsInjectLife1=DrugsInjectLife01*1; drop DrugsInjectLife01;

	if q4=1 then DemoEth03='5';
	else if q4=2 or q4=5 then DemoEth03='4';
	else if q4=3 then DemoEth03='2';
	else if q4=4 then DemoEth03='3';
	else if q4=6 then DemoEth03='1';
	else if q4=7 or q4=8 then DemoEth03='6';
	else DemoEth03=' ';

		DemoEth3=DemoEth03*1; drop DemoEth03;

	if q43=1 then AlcoholDaySP03='1';
	else if q43=2 then AlcoholDaySP03='2';
	else if q43=3 then AlcoholDaySP03='3';
	else if q43=4 then AlcoholDaySP03='4';
	else if q43=5 then AlcoholDaySP03='5';
	else if q43=6 or q43=7 then AlcoholDaySP03='6';
	else AlcoholDaySP03=' ';

		AlcoholDaySP3=AlcoholDaySP03*1; drop AlcoholDaySP03;

	drop q1-q98 qn1-qn98 qnfrcig qnfrvg qnrovwgt qnovwgt qndlype qnanytob qnminpa qnnopa qnasatck bmipct ethorig raceorig qndepo
		 qndepopl qndual qnfrvg2 qnfruit qnveg qnpa0day qnpa7day qnowt qnobese metrost qnstore qnabstsx qnrespsx qntencig
		 q4orig;

run;

/* Format and input data from YRBS 2001 */

data YRBS2001;													/* Create SAS dataset YRBS2001 */
	set mydata.YRBS2001;										/* The SET statement reads data from an existing SAS dataset */

	year=2001;
	AlcoholLife1=q40*1; AlcoholDay2=q42*1; AlcoholBinge4=q43*1;															/* Alcohol */
	DemoAge1=q1*1; DemoSex2=q2*1;																						/* Demographics */
	DrugsMarLife1=q45*1; DrugsMarDay2=q47*1; DrugsMarDaySP3=q48*1; DrugsCocaLife1=q49*1;									/* Drugs */
	DrugsCocaDay2=q50*1; DrugsInhaLife1=q51*1; DrugsInhaDay2=q52*1; DrugsHeroLife1=q53*1;
	DrugsMethLife1=q54*1; DrugsSteroLife1=q55*1; DrugsEcstaLife1=q90*1; DrugsComboLife1=q91*1;
	EduGrades1=q7*1; 																									/* Education */
	ExerHardActive1=q80*1; ExerSoftActive1=q81*1; ExerStrength4=q82*1; ExerTeam6=q86*1; 									/* Exercise */
	HealthDoctor1=q93*1; HealthDentist2=q94*1; 																			/* Health */
	MoodDep1=q23*1; MoodConsiderS2=q24*1; MoodPlanS3=q25*1; MoodAttemptS4=q26*1; MoodSeriousS5=q27*1;							/* Mood */
	SexForce1=q22*1; SexHist2=q58*1; SexAge3=q59*1; SexNumLife4=q60*1; SexNumMonth4=q61*1; SexSub5=q62*1;						/* Sexuality */
	SexPregnant8=q65*1;				
	TobacTry1=q28*1; TobacDaily2=q35*1; TobacDays4=q30*1; TobacDaysSP4=q34*1; TobacAmount5=q31*1;								/* Tobacco */
	VehicleHelmet1=q8*1; VehicleOtherSB2=q88*1; VehicleSelfSB2=q10*1; VehicleOtherD3=q11*1; 								/* Vehicle */
	VehicleSelfD3=q12*1;
	ViolMultWeap1=q13*1; ViolMultWeapSP1=q15*1; ViolGun1=q14*1; ViolUnsafe2=q16*1; ViolThreatSP2=q17*1;						/* Violence */
	ViolFight3=q18*1; ViolFightSP3=q20*1; ViolInjury3=q19*1; ViolSigOth4=q21*1;
	WeightThink1=q66*1; WeightTry1=q67*1; WeightFast2=q70*1; WeightSupp2=q71*1; WeightPurge2=q72*1;							/* Weight */

	if q32=1 then TobacGet06='1';
	else if q32=2 then TobacGet06='2';
	else if q32=3 then TobacGet06='3';
	else if q32=4 then TobacGet06='4';
	else if q32=5 then TobacGet06='5';
	else if q32=7 then TobacGet06='6';
	else if q32=6 or q32=8 then TobacGet06='7';
	else TobacGet06=' ';

		TobacGet6=TobacGet06*1; drop TobacGet06;

	if q69=1 or q68=1 then WeightDietExer02='1';																		/* Adjusted */
	else if q69=2 and q68=2 then WeightDietExer02='2';
	else WeightDietExer02=' ';

		WeightDietExer2=WeightDietExer02*1; drop WeightDietExer02;

	if q39=1 then TobacCigar09='2';
	else if q39=2 or q39=3 or q39=4 or q39=5 or q39=6 or q39=7 then TobacCigar09='1';
	else TobacCigar09=' ';

		TobacCigar9=TobacCigar09*1; drop TobacCigar09;

	if q38=1 then TobacChewSP08='2';
	else if q38=2 or q38=3 or q38=4 or q38=5 or q38=6 or q38=7 then TobacChewSP08='1';
	else TobacChewSP08=' ';

		TobacChewSP8=TobacChewSP08*1; drop TobacChewSP08;

	if q37=1 then TobacChew07='2';
	else if q37=2 or q37=3 or q37=4 or q37=5 or q37=6 or q37=7 then TobacChew07='1';
	else TobacChew07=' ';

		TobacChew7=TobacChew07*1; drop TobacChew07;

	if q36=2 then TobacQuit03='1';
	else if q36=3 then TobacQuit03='2';
	else TobacQuit03=' ';

		TobacQuit3=TobacQuit03*1; drop TobacQuit03;

	if q64=2 then SexProtect07='2';
	else if q64=3 or q64=4 or q64=5 or q64=6 or q64=7 then SexProtect07='1';
	else if q64=8 then SexProtect07='3';
	else SexProtect07=' ';

		SexProtect7=SexProtect07*1; drop SexProtect07;

	if q92=1 or q92=3 then ExerInjury07='2';
	else if q92=2 then ExerInjury07='1';
	else ExerInjury07=' ';

		ExerInjury7=ExerInjury07*1; drop ExerInjury07;

	if q56=1 then DrugsInjectLife01='2';
	else if q56=2 or q56=3 then DrugsInjectLife01='1';
	else DrugsInjectLife01=' ';

		DrugsInjectLife1=DrugsInjectLife01*1; drop DrugsInjectLife01;

	if q4=1 then DemoEth03='5';
	else if q4=2 or q4=5 then DemoEth03='4';
	else if q4=3 then DemoEth03='2';
	else if q4=4 then DemoEth03='3';
	else if q4=6 then DemoEth03='1';
	else if q4=7 or q4=8 then DemoEth03='6';
	else DemoEth03=' ';

		DemoEth3=DemoEth03*1; drop DemoEth03;

	if q44=1 then AlcoholDaySP03='1';
	else if q44=2 then AlcoholDaySP03='2';
	else if q44=3 then AlcoholDaySP03='3';
	else if q44=4 then AlcoholDaySP03='4';
	else if q44=5 then AlcoholDaySP03='5';
	else if q44=6 or q44=7 then AlcoholDaySP03='6';
	else AlcoholDaySP03=' ';
	
		AlcoholDaySP3=AlcoholDaySP03*1; drop AlcoholDaySP03;

	drop q1-q98 qn1-qn98 qnfrcig qnfrvg qnrovwgt qnovwgt qndlype qnanytob qnminpa qnnopa qnasatck bmipct ethorig raceorig qndepo
		 qndepopl qndual qnfrvg2 qnfruit qnveg qnpa0day qnpa7day qnowt qnobese metrost qnstore qnabstsx qnrespsx qntencig
		 q4orig;

run;

/* Format and input data from YRBS 2003 */

data YRBS2003;													/* Create SAS dataset YRBS2003 */
	set mydata.YRBS2003;										/* The SET statement reads data from an existing SAS dataset */

	year=2003;
	AlcoholLife1=q39*1; AlcoholDay2=q41*1; AlcoholBinge4=q42*1;															/* Alcohol */
	DemoAge1=q1*1; DemoSex2=q2*1;																						/* Demographics */
	DrugsMarLife1=q44*1; DrugsMarDay2=q46*1; DrugsMarDaySP3=q47*1; DrugsCocaLife1=q48*1;									/* Drugs */
	DrugsCocaDay2=q49*1; DrugsInhaLife1=q50*1; DrugsInhaDay2=q51*1; DrugsHeroLife1=q52*1;
	DrugsMethLife1=q53*1; DrugsSteroLife1=q55*1; DrugsEcstaLife1=q54*1; DrugsComboLife1=q91*1;
	EduGrades1=q7*1;																									/* Education */
	ExerHardActive1=q80*1; ExerSoftActive1=q81*1; ExerStrength4=q82*1; ExerTeam6=q86*1;										/* Exercise */
	HealthDentist2=q94*1; 																							/* Health */
	MoodDep1=q23*1; MoodConsiderS2=q24*1; MoodPlanS3=q25*1; MoodAttemptS4=q26*1; MoodSeriousS5=q27*1;							/* Mood */
	SexForce1=q22*1; SexHist2=q58*1; SexAge3=q59*1; SexNumLife4=q60*1; SexNumMonth4=q61*1; 									/* Sexuality */
	SexSub5=q62*1; SexPregnant8=q65*1; 	
	TobacTry1=q28*1; TobacDaily2=q34*1; TobacDays4=q30*1; TobacDaysSP4=q33*1; TobacAmount5=q31*1;								/* Tobacco */
	VehicleOtherSB2=q88*1; VehicleSelfSB2=q9*1; VehicleOtherD3=q10*1; VehicleSelfD3=q11*1;									/* Vehicle */
	ViolMultWeap1=q12*1; ViolMultWeapSP1=q14*1; ViolGun1=q13*1; ViolUnsafe2=q15*1; ViolThreatSP2=q16*1;						/* Violence */
	ViolDamageSP2=q17*1; ViolFight3=q18*1; ViolFightSP3=q20*1; ViolInjury3=q19*1; ViolSigOth4=q21*1;
	WeightThink1=q66*1; WeightTry1=q67*1; WeightFast2=q70*1; WeightSupp2=q71*1; WeightPurge2=q72*1;							/* Weight */

	if q32=1 then TobacGet06='1';
	else if q32=2 then TobacGet06='2';
	else if q32=3 then TobacGet06='3';
	else if q32=4 then TobacGet06='4';
	else if q32=5 then TobacGet06='5';
	else if q32=7 then TobacGet06='6';
	else if q32=6 or q32=8 then TobacGet06='7';
	else TobacGet06=' ';

		TobacGet6=TobacGet06*1; drop TobacGet06;

	if q69=1 or q68=1 then WeightDietExer02='1';																		/* Adjusted */
	else if q69=2 and q68=2 then WeightDietExer02='2';
	else WeightDietExer02=' ';

		WeightDietExer2=WeightDietExer02*1; drop WeightDietExer02;

	if q38=1 then TobacCigar09='2';
	else if q38=2 or q38=3 or q38=4 or q38=5 or q38=6 or q38=7 then TobacCigar09='1';
	else TobacCigar09=' ';

		TobacCigar9=TobacCigar09*1; drop TobacCigar09;

	if q37=1 then TobacChewSP08='2';
	else if q37=2 or q37=3 or q37=4 or q37=5 or q37=6 or q37=7 then TobacChewSP08='1';
	else TobacChewSP08=' ';

		TobacChewSP8=TobacChewSP08*1; drop TobacChewSP08;

	if q36=1 then TobacChew07='2';
	else if q36=2 or q36=3 or q36=4 or q36=5 or q36=6 or q36=7 then TobacChew07='1';
	else TobacChew07=' ';

		TobacChew7=TobacChew07*1; drop TobacChew07;

	if q35=2 then TobacQuit03='1';
	else if q35=3 then TobacQuit03='2';
	else TobacQuit03=' ';

		TobacQuit3=TobacQuit03*1; drop TobacQuit03;

	if q64=2 then SexProtect07='2';
	else if q64=3 or q64=4 or q64=5 or q64=6 or q64=7 then SexProtect07='1';
	else if q64=8 then SexProtect07='3';
	else SexProtect07=' ';
		
		SexProtect7=SexProtect07*1; drop SexProtect07;

	if q93=1 or q93=3 then ExerInjury07='2';
	else if q93=2 then ExerInjury07='1';
	else ExerInjury07=' ';

		ExerInjury7=ExerInjury07*1; drop ExerInjury07;

	if q56=1 then DrugsInjectLife01='2';
	else if q56=2 or q56=3 then DrugsInjectLife01='1';
	else DrugsInjectLife01=' ';

		DrugsInjectLife1=DrugsInjectLife01*1; drop DrugsInjectLife01;

	if q4=1 then DemoEth03='5';
	else if q4=2 or q4=5 then DemoEth03='4';
	else if q4=3 then DemoEth03='2';
	else if q4=4 then DemoEth03='3';
	else if q4=6 then DemoEth03='1';
	else if q4=7 or q4=8 then DemoEth03='6';
	else DemoEth03=' ';

		DemoEth3=DemoEth03*1; drop DemoEth03;

	if q43=1 then AlcoholDaySP03='1';
	else if q43=2 then AlcoholDaySP03='2';
	else if q43=3 then AlcoholDaySP03='3';
	else if q43=4 then AlcoholDaySP03='4';
	else if q43=5 then AlcoholDaySP03='5';
	else if q43=6 or q43=7 then AlcoholDaySP03='6';
	else AlcoholDaySP03=' ';

		AlcoholDaySP3=AlcoholDaySP03*1; drop AlcoholDaySP03;

	drop q1-q98 qn1-qn98 qnfrcig qnfrvg qnrovwgt qnovwgt qndlype qnanytob qnminpa qnnopa qnasatck bmipct ethorig raceorig qndepo
		 qndepopl qndual qnfrvg2 qnfruit qnveg qnpa0day qnpa7day qnowt qnobese metrost qnstore qnabstsx qnrespsx qntencig
		 q4orig;

run;

/* Format and input data from YRBS 2005 */

data YRBS2005;													/* Create SAS dataset YRBS2005 */
	set mydata.YRBS2005;										/* The SET statement reads data from an existing SAS dataset */

	year=2005;
	AlcoholLife1=q39*1; AlcoholDay2=q41*1; AlcoholBinge4=q42*1;															/* Alcohol */
	DemoAge1=q1*1; DemoSex2=q2*1;																						/* Demographics */
	DrugsMarLife1=q44*1; DrugsMarDay2=q46*1; DrugsMarDaySP3=q47*1; DrugsCocaLife1=q48*1;									/* Drugs */
	DrugsCocaDay2=q49*1; DrugsInhaLife1=q50*1; DrugsHeroLife1=q51*1;
	DrugsMethLife1=q52*1; DrugsSteroLife1=q54*1; DrugsEcstaLife1=q53*1; DrugsComboLife1=q90*1;
	EduMiss3=q97*1;																									/* Education */
	ExerHardActive1=q78*1; ExerHardActive2=q80*1; ExerSoftActive1=q79*1; ExerTeam6=q84*1;									/* Exercise */
	HealthGeneral3=q7*1; 																								/* Health */
	MoodDep1=q23*1; MoodConsiderS2=q24*1; MoodPlanS3=q25*1; MoodAttemptS4=q26*1; MoodSeriousS5=q27*1;							/* Mood */
	SexForce1=q22*1; SexHist2=q57*1; SexAge3=q58*1; SexNumLife4=q59*1; SexNumMonth4=q60*1; 									/* Sexuality */
	SexSub5=q61*1; 	
	TobacTry1=q28*1; TobacDaily2=q34*1; TobacDays4=q30*1; TobacDaysSP4=q33*1; TobacAmount5=q31*1;								/* Tobacco */ 
	VehicleHelmet1=q88*1; VehicleSelfSB2=q9*1; VehicleOtherD3=q10*1; VehicleSelfD3=q11*1;									/* Vehicle */
	ViolMultWeap1=q12*1; ViolMultWeapSP1=q14*1; ViolGun1=q13*1; ViolUnsafe2=q15*1; ViolThreatSP2=q16*1;						/* Violence */
	ViolDamageSP2=q17*1; ViolFight3=q18*1; ViolFightSP3=q20*1; ViolInjury3=q19*1; ViolSigOth4=q21*1;
	WeightThink1=q64*1; WeightTry1=q65*1; WeightFast2=q68*1; WeightSupp2=q69*1; WeightPurge2=q70*1;							/* Weight */

	if q32=1 then TobacGet06='1';
	else if q32=2 then TobacGet06='2';
	else if q32=3 then TobacGet06='3';
	else if q32=4 then TobacGet06='4';
	else if q32=5 then TobacGet06='5';
	else if q32=7 then TobacGet06='6';
	else if q32=6 or q32=8 then TobacGet06='7';
	else TobacGet06=' ';

		TobacGet6=TobacGet06*1; drop TobacGet06;

	if q66=1 or q67=1 then WeightDietExer02='1';																		/* Adjusted */
	else if q66=2 and q67=2 then WeightDietExer02='2';
	else WeightDietExer02=' ';

		WeightDietExer2=WeightDietExer02*1; drop WeightDietExer02;

	if q38=1 then TobacCigar09='2';
	else if q38=2 or q38=3 or q38=4 or q38=5 or q38=6 or q38=7 then TobacCigar09='1';
	else TobacCigar09=' ';

		TobacCigar9=TobacCigar09*1; drop TobacCigar09;

	if q37=1 then TobacChewSP08='2';
	else if q37=2 or q37=3 or q37=4 or q37=5 or q37=6 or q37=7 then TobacChewSP08='1';
	else TobacChewSP08=' ';

		TobacChewSP8=TobacChewSP08*1; drop TobacChewSP08;

	if q36=1 then TobacChew07='2';
	else if q36=2 or q36=3 or q36=4 or q36=5 or q36=6 or q36=7 then TobacChew07='1';
	else TobacChew07=' ';

		TobacChew7=TobacChew07*1; drop TobacChew07;

	if q35=2 then TobacQuit03='1';
	else if q35=3 then TobacQuit03='2';
	else TobacQuit03=' ';

		TobacQuit3=TobacQuit03*1; drop TobacQuit03;

	if q63=2 then SexProtect07='2';
	else if q63=3 or q63=4 or q63=5 or q63=6 or q63=7 then SexProtect07='1';
	else if q63=8 then SexProtect07='3';
	else SexProtect07=' ';

		SexProtect7=SexProtect07*1; drop SexProtect07;

	if q92=1 or q92=3 then ExerInjury07='2';
	else if q92=2 then ExerInjury07='1';
	else ExerInjury07=' ';

		ExerInjury7=ExerInjury07*1; drop ExerInjury07;

	if q55=1 then DrugsInjectLife01='2';
	else if q55=2 or q55=3 then DrugsInjectLife01='1';
	else DrugsInjectLife01=' ';

		DrugsInjectLife1=DrugsInjectLife01*1; drop DrugsInjectLife01;

	if q4=1 then DemoEth03='5';
	else if q4=2 or q4=5 then DemoEth03='4';
	else if q4=3 then DemoEth03='2';
	else if q4=4 then DemoEth03='3';
	else if q4=6 then DemoEth03='1';
	else if q4=7 or q4=8 then DemoEth03='6';
	else DemoEth03=' ';

		DemoEth3=DemoEth03*1; drop DemoEth03;

	if q43=1 then AlcoholDaySP03='1';
	else if q43=2 then AlcoholDaySP03='2';
	else if q43=3 then AlcoholDaySP03='3';
	else if q43=4 then AlcoholDaySP03='4';
	else if q43=5 then AlcoholDaySP03='5';
	else if q43=6 or q43=7 then AlcoholDaySP03='6';
	else AlcoholDaySP03=' ';

		AlcoholDaySP3=AlcoholDaySP03*1; drop AlcoholDaySP03;

	drop q1-q98 qn1-qn98 qnfrcig qnfrvg qnrovwgt qnovwgt qndlype qnanytob qnminpa qnnopa qnasatck bmipct ethorig raceorig qndepo
		 qndepopl qndual qnfrvg2 qnfruit qnveg qnpa0day qnpa7day qnowt qnobese metrost qnstore qnabstsx qnrespsx qntencig
		 q4orig;

run;

/* Format and input data from YRBS 2007 */

data YRBS2007;													/* Create SAS dataset YRBS2007 */
	set mydata.YRBS2007;										/* The SET statement reads data from an existing SAS dataset */

	year=2007;
	AlcoholLife1=q39*1; AlcoholDay2=q41*1; AlcoholBinge4=q42*1; AlcoholGet5=q43*1;											/* Alcohol */
	DemoAge1=q1*1; DemoSex2=q2*1; 																						/* Demographics */
	DrugsMarLife1=q45*1; DrugsMarDay2=q47*1; DrugsMarDaySP3=q48*1; DrugsCocaLife1=q49*1;									/* Drugs */
	DrugsCocaDay2=q50*1; DrugsInhaLife1=q51*1; DrugsHeroLife1=q52*1; DrugsMethLife1=q53*1; 
	DrugsSteroLife1=q55*1; DrugsEcstaLife1=q54*1; DrugsComboLife1=q89*1;
	ExerHardActive1=q90*1; ExerHardActive2=q80*1; ExerSoftActive1=q91*1; ExerTeam6=q84*1;									/* Exercise */
	Sleep1=q97*1; HealthGeneral3=q98*1;																					/* Health */
	MoodDep1=q23*1; MoodConsiderS2=q24*1; MoodPlanS3=q25*1; MoodAttemptS4=q26*1; MoodSeriousS5=q27*1;							/* Mood */
	SexForce1=q22*1; SexHist2=q58*1; SexAge3=q59*1; SexNumLife4=q60*1; SexNumMonth4=q61*1; SexSub5=q62*1;						/* Sexuality */
	TobacTry1=q28*1; TobacDaily2=q34*1; TobacDays4=q30*1; TobacDaysSP4=q33*1; TobacAmount5=q31*1;								/* Tobacco */
	VehicleHelmet1=q88*1; VehicleSelfSB2=q9*1; VehicleOtherD3=q10*1; VehicleSelfD3=q11*1;									/* Vehicle */
	ViolMultWeap1=q12*1; ViolMultWeapSP1=q14*1; ViolGun1=q13*1; ViolUnsafe2=q15*1; ViolThreatSP2=q16*1;						/* Violence */
	ViolDamageSP2=q17*1; ViolFight3=q18*1; ViolFightSP3=q20*1; ViolInjury3=q19*1; ViolSigOth4=q21*1;
	WeightThink1=q65*1; WeightTry1=q66*1; WeightFast2=q69*1; WeightSupp2=q70*1; WeightPurge2=q71*1;							/* Weight */
	
	if q32=1 then TobacGet06='1';
	else if q32=2 then TobacGet06='2';
	else if q32=3 then TobacGet06='3';
	else if q32=4 then TobacGet06='4';
	else if q32=5 then TobacGet06='5';
	else if q32=7 then TobacGet06='6';
	else if q32=6 or q32=8 then TobacGet06='7';
	else TobacGet06=' ';

		TobacGet6=TobacGet06*1; drop TobacGet06;

	if q67=1 or q68=1 then WeightDietExer02='1';																		/* Adjusted */
	else if q67=2 and q68=2 then WeightDietExer02='2';
	else WeightDietExer02=' ';

		WeightDietExer2=WeightDietExer02*1; drop WeightDietExer02;

	if q38=1 then TobacCigar09='2';
	else if q38=2 or q38=3 or q38=4 or q38=5 or q38=6 or q38=7 then TobacCigar09='1';
	else TobacCigar09=' ';

		TobacCigar9=TobacCigar09*1; drop TobacCigar09;

	if q37=1 then TobacChewSP08='2';
	else if q37=2 or q37=3 or q37=4 or q37=5 or q37=6 or q37=7 then TobacChewSP08='1';
	else TobacChewSP08=' ';

		TobacChewSP8=TobacChewSP08*1; drop TobacChewSP08;

	if q36=1 then TobacChew07='2';
	else if q36=2 or q36=3 or q36=4 or q36=5 or q36=6 or q36=7 then TobacChew07='1';
	else TobacChew07=' ';

		TobacChew7=TobacChew07*1; drop TobacChew07;

	if q35=2 then TobacQuit03='1';
	else if q35=3 then TobacQuit03='2';
	else TobacQuit03=' ';

		TobacQuit3=TobacQuit03*1; drop TobacQuit03;

	if q64=2 then SexProtect07='2';
	else if q64=3 or q64=4 or q64=5 or q64=6 or q64=7 then SexProtect07='1';
	else if q64=8 then SexProtect07='3';
	else SexProtect07=' ';

		SexProtect7=SexProtect07*1; drop SexProtect07;

	if q93=1 or q93=3 then ExerInjury07='2';
	else if q93=2 then ExerInjury07='1';
	else ExerInjury07=' ';

		ExerInjury7=ExerInjury07*1; drop ExerInjury07;

	if q56=1 then DrugsInjectLife01='2';
	else if q56=2 or q56=3 then DrugsInjectLife01='1';
	else DrugsInjectLife01=' ';

		DrugsInjectLife1=DrugsInjectLife01*1; drop DrugsInjectLife01;

	if q4=1 then DemoEth03='3';
	else if q5='A' then DemoEth03='5';
	else if q5='B' or q5='D' then DemoEth03='4';
	else if q5='C' then DemoEth03='2';
	else if q5='E' then DemoEth03='1';
	else DemoEth03='6';

		DemoEth3=DemoEth03*1; drop DemoEth03;

	if q44=1 then AlcoholDaySP03='1';
	else if q44=2 then AlcoholDaySP03='2';
	else if q44=3 then AlcoholDaySP03='3';
	else if q44=4 then AlcoholDaySP03='4';
	else if q44=5 then AlcoholDaySP03='5';
	else if q44=6 or q44=7 then AlcoholDaySP03='6';
	else AlcoholDaySP03=' ';

		AlcoholDaySP3=AlcoholDaySP03*1; drop AlcoholDaySP03;

	drop q1-q98 qn1-qn98 qnfrcig qnfrvg qnrovwgt qnovwgt qndlype qnanytob qnminpa qnnopa qnasatck bmipct ethorig raceorig qndepo
		 qndepopl qndual qnfrvg2 qnfruit qnveg qnpa0day qnpa7day qnowt qnobese raceeth metrost qnstore qnabstsx qnrespsx qntencig
		 q4orig;

run;

/* Format and input data from YRBS 2009 */

data YRBS2009;													/* Create SAS dataset YRBS2009 */
	set mydata.YRBS2009;										/* The SET statement reads data from an existing SAS dataset */

	year=2009;
	AlcoholLife1=q39*1; AlcoholDay2=q41*1; AlcoholBinge4=q42*1; AlcoholGet5=q43*1;											/* Alcohol */
	DemoAge1=q1*1; DemoSex2=q2*1; 																						/* Demographics */
	DrugsMarLife1=q45*1; DrugsMarDay2=q47*1; DrugsMarDaySP3=q48*1; DrugsCocaLife1=q49*1;									/* Drugs */
	DrugsCocaDay2=q50*1; DrugsInhaLife1=q51*1; DrugsHeroLife1=q52*1; DrugsMethLife1=q53*1; 
	DrugsSteroLife1=q55*1; DrugsEcstaLife1=q54*1; DrugsPrescLife1=q90*1; DrugsComboLife1=q89*1;
	EduGrades1=q98*1;																									/* Education */
	ExerHardActive1=q91*1; ExerHardActive2=q80*1; ExerSoftActive1=q92*1; ExerTeam6=q84*1;									/* Exercise */
	Sleep1=q97*1;																									/* Health */
	MoodDep1=q23*1; MoodConsiderS2=q24*1; MoodPlanS3=q25*1; MoodAttemptS4=q26*1; MoodSeriousS5=q27*1;							/* Mood */
	SexForce1=q21*1; SexHist2=q58*1; SexAge3=q59*1; SexNumLife4=q60*1; SexNumMonth4=q61*1; SexSub5=q62*1;						/* Sexuality */
	TobacTry1=q28*1; TobacDaily2=q34*1; TobacDays4=q30*1; TobacDaysSP4=q33*1; TobacAmount5=q31*1;								/* Tobacco */
	VehicleHelmet1=q88*1; VehicleSelfSB2=q9*1; VehicleOtherD3=q10*1; VehicleSelfD3=q11*1;									/* Vehicle */
	ViolMultWeap1=q12*1; ViolMultWeapSP1=q14*1; ViolGun1=q13*1; ViolUnsafe2=q15*1; ViolThreatSP2=q16*1;						/* Violence */
	ViolFight3=q17*1; ViolFightSP3=q19*1; ViolInjury3=q18*1; ViolSigOth4=q20*1; ViolBullySP5=q22*1;
	WeightThink1=q65*1; WeightTry1=q66*1; WeightFast2=q69*1; WeightSupp2=q70*1; WeightPurge2=q71*1;							/* Weight */
	
	if q32=1 then TobacGet06='1';
	else if q32=2 then TobacGet06='2';
	else if q32=3 then TobacGet06='3';
	else if q32=4 then TobacGet06='4';
	else if q32=5 then TobacGet06='5';
	else if q32=7 then TobacGet06='6';
	else if q32=6 or q32=8 then TobacGet06='7';
	else TobacGet06=' ';

		TobacGet6=TobacGet06*1; drop TobacGet06;

	if q67=1 or q68=1 then WeightDietExer02='1';																		/* Adjusted */
	else if q67=2 and q68=2 then WeightDietExer02='2';
	else WeightDietExer02=' ';

		WeightDietExer2=WeightDietExer02*1; drop WeightDietExer02;

	if q38=1 then TobacCigar09='2';
	else if q38=2 or q38=3 or q38=4 or q38=5 or q38=6 or q38=7 then TobacCigar09='1';
	else TobacCigar09=' ';

		TobacCigar9=TobacCigar09*1; drop TobacCigar09;

	if q37=1 then TobacChewSP08='2';
	else if q37=2 or q37=3 or q37=4 or q37=5 or q37=6 or q37=7 then TobacChewSP08='1';
	else TobacChewSP08=' ';

		TobacChewSP8=TobacChewSP08*1; drop TobacChewSP08;

	if q36=1 then TobacChew07='2';
	else if q36=2 or q36=3 or q36=4 or q36=5 or q36=6 or q36=7 then TobacChew07='1';
	else TobacChew07=' ';

		TobacChew7=TobacChew07*1; drop TobacChew07;

	if q35=2 then TobacQuit03='1';
	else if q35=3 then TobacQuit03='2';
	else TobacQuit03=' ';

		TobacQuit3=TobacQuit03*1; drop TobacQuit03;

	if q64=2 then SexProtect07='2';
	else if q64=3 or q64=4 or q64=5 or q64=6 or q64=7 then SexProtect07='1';
	else if q64=8 then SexProtect07='3';
	else SexProtect07=' ';

		SexProtect7=SexProtect07*1; drop SexProtect07;

	if q56=1 then DrugsInjectLife01='2';
	else if q56=2 or q56=3 then DrugsInjectLife01='1';
	else DrugsInjectLife01=' ';

		DrugsInjectLife1=DrugsInjectLife01*1; drop DrugsInjectLife01;

	if q4=1 then DemoEth03='3';
	else if q5='A' then DemoEth03='5';
	else if q5='B' or q5='D' then DemoEth03='4';
	else if q5='C' then DemoEth03='2';
	else if q5='E' then DemoEth03='1';
	else DemoEth03='6';

		DemoEth3=DemoEth03*1; drop DemoEth03;

	if q44=1 then AlcoholDaySP03='1';
	else if q44=2 then AlcoholDaySP03='2';
	else if q44=3 then AlcoholDaySP03='3';
	else if q44=4 then AlcoholDaySP03='4';
	else if q44=5 then AlcoholDaySP03='5';
	else if q44=6 or q44=7 then AlcoholDaySP03='6';
	else AlcoholDaySP03=' ';

		AlcoholDaySP3=AlcoholDaySP03*1; drop AlcoholDaySP03;

	drop q1-q98 qn1-qn98 qnfrcig qnfrvg qnrovwgt qnovwgt qndlype qnanytob qnminpa qnnopa qnasatck bmipct ethorig raceorig qndepo
		 qndepopl qndual qnfrvg2 qnfruit qnveg qnpa0day qnpa7day qnowt qnobese raceeth metrost qnstore qnabstsx qnrespsx qntencig
		 q4orig;

run;

/* Format and input data from YRBS 2011 */

data YRBS2011;													/* Create SAS dataset YRBS2011 */
	set mydata.YRBS2011;										/* The SET statement reads data from an existing SAS dataset */

	year=2011;
	AlcoholLife1=q40*1; AlcoholDay2=q42*1; AlcoholBinge4=q43*1; AlcoholGet5=q44*1;											/* Alcohol */
	DemoAge1=q1*1; DemoSex2=q2*1; 																						/* Demographics */
	DrugsMarLife1=q46*1; DrugsMarDay2=q48*1; DrugsMarDaySP3=q49*1; DrugsCocaLife1=q50*1;									/* Drugs */
	DrugsCocaDay2=q51*1; DrugsInhaLife1=q52*1; DrugsHeroLife1=q53*1; DrugsMethLife1=q54*1; 
	DrugsSteroLife1=q56*1; DrugsEcstaLife1=q55*1; DrugsPrescLife1=q57*1; DrugsComboLife1=q89*1;																								/* Education */
	ExerHardActive2=q79*1; ExerStrength4=q92*1; ExerTeam6=q83*1;															/* Exercise */
	Sleep1=q96*1;																										/* Health */
	MoodDep1=q24*1; MoodConsiderS2=q25*1; MoodPlanS3=q26*1; MoodAttemptS4=q27*1; MoodSeriousS5=q28*1;							/* Mood */
	SexForce1=q21*1; SexHist2=q60*1; SexAge3=q61*1; SexNumLife4=q62*1; SexNumMonth4=q63*1; SexSub5=q64*1;						/* Sexuality */
	TobacTry1=q29*1; TobacDaily2=q35*1; TobacDays4=q31*1; TobacDaysSP4=q34*1; TobacAmount5=q32*1;								/* Tobacco */
	VehicleSelfSB2=q9*1; VehicleOtherD3=q10*1; VehicleSelfD3=q11*1;														/* Vehicle */
	ViolMultWeap1=q12*1; ViolMultWeapSP1=q14*1; ViolGun1=q13*1; ViolUnsafe2=q15*1; ViolThreatSP2=q16*1;						/* Violence */
	ViolFight3=q17*1; ViolFightSP3=q19*1; ViolInjury3=q18*1; ViolSigOth4=q20*1; ViolBullySP5=q22*1;
	ViolDamageSP2=q88*1; ViolBullyElec5=q23*1;
	WeightThink1=q67*1; WeightTry1=q68*1; WeightFast2=q69*1; WeightSupp2=q70*1; WeightPurge2=q71*1;							/* Weight */

	if q33=1 then TobacGet06='1';
	else if q33=2 then TobacGet06='2';
	else if q33=3 then TobacGet06='3';
	else if q33=4 then TobacGet06='4';
	else if q33=5 then TobacGet06='5';
	else if q33=7 then TobacGet06='6';
	else if q33=6 or q33=8 then TobacGet06='7';
	else TobacGet06=' ';

		TobacGet6=TobacGet06*1; drop TobacGet06;

	if q39=1 then TobacCigar09='2';
	else if q39=2 or q39=3 or q39=4 or q39=5 or q39=6 or q39=7 then TobacCigar09='1';
	else TobacCigar09=' ';

		TobacCigar9=TobacCigar09*1; drop TobacCigar09;

	if q38=1 then TobacChewSP08='2';
	else if q38=2 or q38=3 or q38=4 or q38=5 or q38=6 or q38=7 then TobacChewSP08='1';
	else TobacChewSP08=' ';

		TobacChewSP8=TobacChewSP08*1; drop TobacChewSP08;

	if q37=1 then TobacChew07='2';
	else if q37=2 or q37=3 or q37=4 or q37=5 or q37=6 or q37=7 then TobacChew07='1';
	else TobacChew07=' ';

		TobacChew7=TobacChew07*1; drop TobacChew07;

	if q36=2 then TobacQuit03='1';
	else if q36=3 then TobacQuit03='2';
	else TobacQuit03=' ';

		TobacQuit3=TobacQuit03*1; drop TobacQuit03;

	if q66=2 then SexProtect07='2';
	else if q66=3 or q66=4 or q66=5 or q66=6 or q66=7 then SexProtect07='1';
	else if q66=8 then SexProtect07='3';
	else SexProtect07=' ';

		SexProtect7=SexProtect07*1; drop SexProtect07;

	if q58=1 then DrugsInjectLife01='2';
	else if q58=2 or q58=3 then DrugsInjectLife01='1';
	else DrugsInjectLife01=' ';

		DrugsInjectLife1=DrugsInjectLife01*1; drop DrugsInjectLife01;

	if q4=1 then DemoEth03='3';
	else if q5='A' then DemoEth03='5';
	else if q5='B' or q5='D' then DemoEth03='4';
	else if q5='C' then DemoEth03='2';
	else if q5='E' then DemoEth03='1';
	else DemoEth03='6';

		DemoEth3=DemoEth03*1; drop DemoEth03;

	if q45=1 then AlcoholDaySP03='1';
	else if q45=2 then AlcoholDaySP03='2';
	else if q45=3 then AlcoholDaySP03='3';
	else if q45=4 then AlcoholDaySP03='4';
	else if q45=5 then AlcoholDaySP03='5';
	else if q45=6 or q45=7 then AlcoholDaySP03='6';
	else AlcoholDaySP03=' ';

		AlcoholDaySP3=AlcoholDaySP03*1; drop AlcoholDaySP03;

	drop q1-q98 qn1-qn98 qnfrcig qnfrvg qnrovwgt qnovwgt qndlype qnanytob qnminpa qnnopa qnasatck bmipct ethorig raceorig qndepo
		 qndepopl qndual qnfrvg2 qnfruit qnveg qnpa0day qnpa7day qnowt qnobese raceeth metrost qnstore qnabstsx qnrespsx qntencig
		 q4orig;

run;

data YRBS_Total_FA;
	set	YRBS1991	YRBS1993	YRBS1995	YRBS1997	YRBS1999	
		YRBS2001	YRBS2003	YRBS2005	YRBS2007	YRBS2009	YRBS2011;

run;

%polychor(data=YRBS_Total_FA, var=AlcoholLife1 AlcoholDay2 AlcoholDaySP3 AlcoholBinge4 AlcoholGet5
								  DrugsMarLife1 DrugsMarDay2 DrugsMarDaySP3 DrugsCocaLife1 DrugsCocaDay2
								  DrugsInhaLife1 DrugsInhaDay2 DrugsHeroLife1 DrugsMethLife1 
								  DrugsSteroLife1 DrugsInjectLife1 DrugsEcstaLife1 DrugsPrescLife1 
								  DrugsComboLife1 ExerHardActive1 ExerHardActive2 ExerSoftActive1
								  ExerStrength4 ExerStretch5 ExerTeam6 HealthDoctor1 HealthDentist2
								  MoodDep1 MoodConsiderS2 MoodPlanS3 MoodAttemptS4 MoodSeriousS5
								  SexForce1 SexHist2 SexAge3 SexNumLife4 SexNumMonth4 SexSub5 SexProtect7 
								  SexPregnant8 SexSTD9 TobacTry1 TobacDaily2 TobacQuit3 TobacDays4 TobacDaysSP4
								  TobacAmount5 TobacGet6 TobacChew7 TobacChewSP8 TobacCigar9 VehicleHelmet1 
								  VehicleOtherSB2 VehicleSelfSB2 VehicleSelfSB2 VehicleOtherD3 VehicleSelfD3
								  ViolMultWeap1 ViolMultWeapSP1 ViolGun1 ViolUnsafe2 ViolThreatSP2 ViolDamageSP2
								  ViolFight3 ViolFightSP3 ViolInjury3 ViolSigOth4 ViolWhom4 WeightTry1 WeightThink1
								  WeightDietExer2 WeightFast2 WeightSupp2 WeightPurge2,
		  out=YRBS_Total, type=corr);

/* Factor Analysis for Variable Categories */

proc corr data=YRBS_Total nocorr alpha nomiss;
	var AlcoholDay2 AlcoholDaySP3 AlcoholBinge4;
run;

proc factor data=YRBS_Total
	method=prinit 
	priors=smc 
	scree 
	residuals 
	rotate=promax
	corr 
	heywood 
	plots=(scree initloadings preloadings loadings);
	var AlcoholDay2 AlcoholDaySP3 AlcoholBinge4;
run;

proc corr data=YRBS_Total nocorr alpha nomiss;
	var DrugsMarLife1 DrugsMarDay2 DrugsComboLife1  DrugsPrescLife1
		DrugsMarDaySP3 DrugsCocaLife1 DrugsCocaDay2 DrugsInhaLife1
		DrugsHeroLife1 DrugsMethLife1 DrugsSteroLife1 DrugsInjectLife1 DrugsEcstaLife1;
run;

proc factor data=YRBS_Total
	method=prinit 
	priors=max 
	scree 
	residuals 
	rotate=promax
	corr 
	heywood 
	plots=(scree initloadings preloadings loadings);
	var DrugsMarLife1 DrugsMarDay2 DrugsComboLife1  DrugsPrescLife1
		DrugsMarDaySP3 DrugsCocaLife1 DrugsCocaDay2 DrugsInhaLife1
		DrugsHeroLife1 DrugsMethLife1 DrugsSteroLife1 DrugsInjectLife1 DrugsEcstaLife1;
run;

proc corr data=YRBS_Total nocorr alpha nomiss;
	var DrugsMarLife1 DrugsMarDay2 DrugsComboLife1
		DrugsMarDaySP3 DrugsCocaLife1 DrugsCocaDay2 DrugsInhaLife1 DrugsInhaDay2 
		DrugsHeroLife1 DrugsMethLife1 DrugsSteroLife1 DrugsInjectLife1 DrugsEcstaLife1;
run;

proc factor data=YRBS_Total
	method=prinit 
	priors=max 
	scree 
	residuals 
	rotate=promax
	corr 
	heywood 
	plots=(scree initloadings preloadings loadings);
	var DrugsMarLife1 DrugsMarDay2 DrugsComboLife1
		DrugsMarDaySP3 DrugsCocaLife1 DrugsCocaDay2 DrugsInhaLife1 DrugsInhaDay2 
		DrugsHeroLife1 DrugsMethLife1 DrugsSteroLife1 DrugsInjectLife1 DrugsEcstaLife1;
run;

proc corr data=YRBS_Total nocorr alpha nomiss;
	var ExerHardActive1 ExerStrength4 ExerStretch5 ExerTeam6;
run;

proc factor data=YRBS_Total
	method=prinit 
	priors=smc 
	scree 
	residuals 
	rotate=promax
	corr 
	heywood 
	plots=(scree initloadings preloadings loadings);
	var ExerHardActive1 ExerStrength4 ExerStretch5 ExerTeam6;
run;

proc corr data=YRBS_Total nocorr alpha nomiss;
	var ExerHardActive1 ExerSoftActive1 ExerStrength4 ExerTeam6;
run;

proc factor data=YRBS_Total
	method=prinit 
	priors=smc 
	scree 
	residuals 
	rotate=promax
	corr 
	heywood 
	plots=(scree initloadings preloadings loadings);
	var ExerHardActive1 ExerSoftActive1 ExerStrength4 ExerTeam6;
run;

proc corr data=YRBS_Total nocorr alpha nomiss;
	var ExerHardActive1 ExerHardActive2 ExerSoftActive1 ExerTeam6;
run;

proc factor data=YRBS_Total
	method=prinit 
	priors=smc 
	scree 
	residuals 
	rotate=promax
	corr 
	heywood 
	plots=(scree initloadings preloadings loadings);
	var ExerHardActive1 ExerHardActive2 ExerSoftActive1 ExerTeam6;
run;

proc corr data=YRBS_Total nocorr alpha nomiss;
	var MoodDep1 MoodConsiderS2 MoodPlanS3 MoodAttemptS4 MoodSeriousS5 ;
run;

proc factor data=YRBS_Total
	method=prinit 
	priors=smc 
	scree 
	residuals 
	rotate=promax
	corr 
	heywood 
	plots=(scree initloadings preloadings loadings);
	var MoodDep1 MoodConsiderS2 MoodPlanS3 MoodAttemptS4 MoodSeriousS5 ;
run;

proc corr data=YRBS_Total nocorr alpha nomiss;
	var SexForce1 SexAge3 SexProtect7 SexPregnant8;
run;

proc factor data=YRBS_Total
	method=prinit 
	priors=smc 
	scree 
	residuals 
	rotate=promax
	corr 
	heywood 
	plots=(scree initloadings preloadings loadings);
	var SexForce1 SexAge3 SexProtect7 SexPregnant8;
run;

proc corr data=YRBS_Total nocorr alpha nomiss;
	var SexForce1 SexNumLife4 SexProtect7 SexPregnant8;
run;

proc factor data=YRBS_Total
	method=prinit 
	priors=smc 
	scree 
	residuals 
	rotate=promax
	corr 
	heywood 
	plots=(scree initloadings preloadings loadings);
	var SexForce1 SexNumLife4 SexProtect7 SexPregnant8;
run;

proc corr data=YRBS_Total nocorr alpha nomiss;
	var SexForce1 SexNumMonth4 SexSub5  SexProtect7 SexPregnant8;
run;

proc factor data=YRBS_Total
	method=prinit 
	priors=smc 
	scree 
	residuals 
	rotate=promax
	corr 
	heywood 
	plots=(scree initloadings preloadings loadings);
	var SexForce1 SexNumMonth4 SexSub5 SexProtect7 SexPregnant8;
run;

proc corr data=YRBS_Total nocorr alpha nomiss;
	var TobacDaily2 TobacQuit3 TobacDaysSP4 TobacAmount5
		TobacChew7 TobacChewSP8 TobacCigar9;
run;

proc factor data=YRBS_Total
	method=prinit 
	priors=max 
	scree 
	residuals 
	rotate=promax
	corr 
	heywood 
	plots=(scree initloadings preloadings loadings);
	var TobacDaily2 TobacQuit3 TobacDaysSP4 TobacAmount5
		TobacChew7 TobacChewSP8 TobacCigar9;
run;

proc corr data=YRBS_Total nocorr alpha nomiss;
	var TobacDaily2 TobacQuit3 TobacDays4 TobacDaysSP4 
		TobacChew7 TobacChewSP8 TobacCigar9;
run;

proc factor data=YRBS_Total
	method=prinit 
	priors=max 
	scree 
	residuals 
	rotate=promax
	corr 
	heywood 
	plots=(scree initloadings preloadings loadings);
	var TobacDaily2 TobacQuit3 TobacDays4 TobacDaysSP4 
		TobacChew7 TobacChewSP8 TobacCigar9;
run;

proc corr data=YRBS_Total nocorr alpha nomiss;
	var VehicleHelmet1 VehicleOtherSB2 VehicleSelfSB2 VehicleOtherD3 VehicleSelfD3 ;
run;

proc factor data=YRBS_Total
	method=prinit 
	priors=smc 
	scree 
	residuals 
	rotate=promax
	maxiter=100
	corr 
	heywood 
	plots=(scree initloadings preloadings loadings);
	var VehicleHelmet1 VehicleOtherSB2 VehicleSelfSB2 VehicleOtherD3 VehicleSelfD3 ;
run;


proc corr data=YRBS_Total nocorr alpha nomiss;
	var ViolMultWeap1 ViolMultWeapSP1 ViolGun1 ViolUnsafe2 ViolThreatSP2 ViolDamageSP2 ViolFight3 
		ViolFightSP3 ViolInjury3 ViolSigOth4;
run;

proc factor data=YRBS_Total
	method=prinit 
	priors=max 
	scree 
	residuals 
	rotate=promax
	corr 
	heywood 
	plots=(scree initloadings preloadings loadings);
	var ViolMultWeap1 ViolMultWeapSP1 ViolGun1 ViolUnsafe2 ViolThreatSP2 ViolDamageSP2 ViolFight3 
		ViolFightSP3 ViolInjury3 ViolSigOth4;
run;

proc corr data=YRBS_Total nocorr alpha nomiss;
	var ViolMultWeap1 ViolMultWeapSP1 ViolGun1 ViolUnsafe2 ViolThreatSP2 ViolDamageSP2 ViolFight3 
		ViolFightSP3 ViolInjury3;
run;

proc factor data=YRBS_Total
	method=prinit 
	priors=max 
	scree 
	residuals 
	rotate=promax
	corr 
	heywood 
	plots=(scree initloadings preloadings loadings);
	var ViolMultWeap1 ViolMultWeapSP1 ViolGun1 ViolUnsafe2 ViolThreatSP2 ViolDamageSP2 ViolFight3 
		ViolFightSP3 ViolInjury3;
run;

proc corr data=YRBS_Total nocorr alpha nomiss;
	var WeightThink1 WeightTry1 WeightDietExer2 WeightFast2 WeightSupp2 WeightPurge2;
run;

proc factor data=YRBS_Total
	method=prinit 
	priors=smc 
	scree 
	residuals 
	rotate=promax
	corr 
	heywood 
	plots=(scree initloadings preloadings loadings);
	var WeightThink1 WeightTry1 WeightDietExer2 WeightFast2 WeightSupp2 WeightPurge2;
run;

ods graphics off;
