*************************************************************;
/*    WiilSU2014_Analysis.sas

Directory:  D:\WiilSU_2014\WiilSU Analysis
            
Author:  Deanna Naomi Schreiber-Gregory

Created:  February 26th, 2014

Revised:  March 7th, 2014

Purpose/Abstract:  This Program performs a factor analysis of 
				   numeric-converted variables for the YRBSS
				   project.

				   Insert conversions directly into renaming of
				   variables: ie, AlcoholLife1=q31*1

Input data file ----------------------------------------------
	YRBS1991.dat
	YRBS1993.dat
	YRBS1995.dat
	YRBS1997.dat
	YRBS1999.dat
	YRBS2001.dat
	YRBS2003.dat
	YRBS2005.dat
	YRBS2007.dat
	YRBS2009.dat
	YRBS2011.dat

Created Variables --------------------------------------------
   Too Many: concatenated variables based on excel File
   D:\WiilSU_2014\WiilSU Analysis\Application\Survey Questions.xlsx

Data Source:  CDC
*/
**************************************************************;

/* Tell SAS where to find the data files and formats */

OPTIONS NODATE NONUMBER NOCENTER SKIP=0;
libname mydata 'D:\WiilSU_2014\WiilSU Analysis';			/* Tells SAS where the data is */
libname library 'D:\WiilSU_2014\WiilSU Analysis';		/* Tells SAS where the formats are */

/* ODS RTF; */
title1 "YRBSS Analysis - WiilSU 2014";

ods graphics on;

/* Format and input data from YRBS 2011 */

data YRBS2011_FA;													/* Create SAS dataset YRBS2011 */
	set mydata.YRBS2011;										/* The SET statement reads data from an existing SAS dataset */

	year=2011;
	AlcoholLife1=q40*1; AlcoholDay2=q42*1; AlcoholBinge4=q43*1; AlcoholGet5=q44*1;											/* Alcohol */
	DemoAge1=q1*1; DemoSex2=q2*1; 																						/* Demographics */
	DrugsMarLife1=q46*1; DrugsMarDay2=q48*1; DrugsMarDaySP3=q49*1; DrugsCocaLife1=q50*1;									/* Drugs */
	DrugsCocaDay2=q51*1; DrugsInhaLife1=q52*1; DrugsHeroLife1=q53*1; DrugsMethLife1=q54*1; 
	DrugsSteroLife1=q56*1; DrugsEcstaLife1=q55*1; DrugsPrescLife1=q57*1; DrugsComboLife1=q89*1;																								/* Education */
	ExerHardActive2=q79*1; ExerStrength4=q92*1; ExerTeam6=q83*1;															/* Exercise */
	Sleep1=q96*1;																										/* Health */
	MoodDep1=q24*1; MoodConsiderS2=q25*1; MoodPlanS3=q26*1; MoodAttemptS4=q27*1; MoodSeriousS5=q28*1;							/* Mood */
	SexForce1=q21*1; SexHist2=q60*1; SexAge3=q61*1; SexNumLife4=q62*1; SexNumMonth4=q63*1; SexSub5=q64*1;						/* Sexuality */
	TobacTry1=q29*1; TobacDaily2=q35*1; TobacDays4=q31*1; TobacDaysSP4=q34*1; TobacAmount5=q32*1;								/* Tobacco */
	VehicleSelfSB2=q9*1; VehicleOtherD3=q10*1; VehicleSelfD3=q11*1;														/* Vehicle */
	ViolMultWeap1=q12*1; ViolMultWeapSP1=q14*1; ViolGun1=q13*1; ViolUnsafe2=q15*1; ViolThreatSP2=q16*1;						/* Violence */
	ViolFight3=q17*1; ViolFightSP3=q19*1; ViolInjury3=q18*1; ViolSigOth4=q20*1; ViolBullySP5=q22*1;
	ViolDamageSP2=q88*1; ViolBullyElec5=q23*1;
	WeightThink1=q67*1; WeightTry1=q68*1; WeightFast2=q69*1; WeightSupp2=q70*1; WeightPurge2=q71*1;							/* Weight */

	if q33=1 then TobacGet06='1';
	else if q33=2 then TobacGet06='2';
	else if q33=3 then TobacGet06='3';
	else if q33=4 then TobacGet06='4';
	else if q33=5 then TobacGet06='5';
	else if q33=7 then TobacGet06='6';
	else if q33=6 or q33=8 then TobacGet06='7';
	else TobacGet06=' ';

		TobacGet6=TobacGet06*1; drop TobacGet06;

	if q39=1 then TobacCigar09='2';
	else if q39=2 or q39=3 or q39=4 or q39=5 or q39=6 or q39=7 then TobacCigar09='1';
	else TobacCigar09=' ';

		TobacCigar9=TobacCigar09*1; drop TobacCigar09;

	if q38=1 then TobacChewSP08='2';
	else if q38=2 or q38=3 or q38=4 or q38=5 or q38=6 or q38=7 then TobacChewSP08='1';
	else TobacChewSP08=' ';

		TobacChewSP8=TobacChewSP08*1; drop TobacChewSP08;

	if q37=1 then TobacChew07='2';
	else if q37=2 or q37=3 or q37=4 or q37=5 or q37=6 or q37=7 then TobacChew07='1';
	else TobacChew07=' ';

		TobacChew7=TobacChew07*1; drop TobacChew07;

	if q36=2 then TobacQuit03='1';
	else if q36=3 then TobacQuit03='2';
	else TobacQuit03=' ';

		TobacQuit3=TobacQuit03*1; drop TobacQuit03;

	if q66=2 then SexProtect07='2';
	else if q66=3 or q66=4 or q66=5 or q66=6 or q66=7 then SexProtect07='1';
	else if q66=8 then SexProtect07='3';
	else SexProtect07=' ';

		SexProtect7=SexProtect07*1; drop SexProtect07;

	if q58=1 then DrugsInjectLife01='2';
	else if q58=2 or q58=3 then DrugsInjectLife01='1';
	else DrugsInjectLife01=' ';

		DrugsInjectLife1=DrugsInjectLife01*1; drop DrugsInjectLife01;

	if q4=1 then DemoEth03='3';
	else if q5='A' then DemoEth03='5';
	else if q5='B' or q5='D' then DemoEth03='4';
	else if q5='C' then DemoEth03='2';
	else if q5='E' then DemoEth03='1';
	else DemoEth03='6';

		DemoEth3=DemoEth03*1; drop DemoEth03;

	if q45=1 then AlcoholDaySP03='1';
	else if q45=2 then AlcoholDaySP03='2';
	else if q45=3 then AlcoholDaySP03='3';
	else if q45=4 then AlcoholDaySP03='4';
	else if q45=5 then AlcoholDaySP03='5';
	else if q45=6 or q45=7 then AlcoholDaySP03='6';
	else AlcoholDaySP03=' ';

		AlcoholDaySP3=AlcoholDaySP03*1; drop AlcoholDaySP03;

	drop q1-q98 qn1-qn98 qnfrcig qnfrvg qnrovwgt qnovwgt qndlype qnanytob qnminpa qnnopa qnasatck bmipct ethorig raceorig qndepo
		 qndepopl qndual qnfrvg2 qnfruit qnveg qnpa0day qnpa7day qnowt qnobese raceeth metrost qnstore qnabstsx qnrespsx qntencig
		 q4orig;

run;

%polychor(data=YRBS2011_FA, var=AlcoholLife1 AlcoholDay2 AlcoholDaySP3 AlcoholBinge4 AlcoholGet5
								  DrugsMarLife1 DrugsMarDay2 DrugsMarDaySP3 DrugsCocaLife1 DrugsCocaDay2
								  DrugsInhaLife1 DrugsHeroLife1 DrugsMethLife1 
								  DrugsSteroLife1 DrugsInjectLife1 DrugsEcstaLife1 DrugsPrescLife1 
								  DrugsComboLife1 
								  SexForce1 SexHist2 SexAge3 SexNumLife4 SexNumMonth4 SexSub5 SexProtect7 
								  TobacTry1 TobacDaily2 TobacQuit3 TobacDays4 TobacDaysSP4
								  TobacAmount5 TobacGet6 TobacChew7 TobacChewSP8 TobacCigar9 
								  VehicleOtherD3 VehicleSelfD3
								  ViolMultWeap1 ViolMultWeapSP1 ViolGun1 ViolUnsafe2 ViolThreatSP2 ViolDamageSP2
								  ViolFight3 ViolFightSP3 ViolInjury3 ViolSigOth4 ViolWhom4,
		  out=YRBS2011, type=corr);

proc corr data=YRBS2011 nocorr alpha nomiss;
	var AlcoholDay2 AlcoholDaySP3 AlcoholBinge4;
run;

proc factor data=YRBS2011
	method=prinit 
	priors=smc 
	scree 
	residuals 
	rotate=promax
	corr 
	heywood 
	plots=(scree initloadings preloadings loadings);
	var AlcoholDay2 AlcoholDaySP3 AlcoholBinge4;
run;

proc corr data=YRBS2011 nocorr alpha nomiss;
	var DrugsMarLife1 DrugsMarDay2 DrugsComboLife1  DrugsPrescLife1
		DrugsMarDaySP3 DrugsCocaLife1 DrugsCocaDay2 DrugsInhaLife1
		DrugsHeroLife1 DrugsMethLife1 DrugsSteroLife1 DrugsInjectLife1 DrugsEcstaLife1;
run;

proc factor data=YRBS2011
	method=prinit 
	priors=max 
	scree 
	residuals 
	rotate=promax
	corr 
	heywood 
	plots=(scree initloadings preloadings loadings);
	var DrugsMarLife1 DrugsMarDay2 DrugsComboLife1  DrugsPrescLife1
		DrugsMarDaySP3 DrugsCocaLife1 DrugsCocaDay2 DrugsInhaLife1
		DrugsHeroLife1 DrugsMethLife1 DrugsSteroLife1 DrugsInjectLife1 DrugsEcstaLife1;
run;

proc corr data=YRBS2011 nocorr alpha nomiss;
	var DrugsMarLife1 DrugsMarDay2 DrugsComboLife1
		DrugsMarDaySP3 DrugsCocaLife1 DrugsCocaDay2 DrugsInhaLife1
		DrugsHeroLife1 DrugsMethLife1 DrugsSteroLife1 DrugsInjectLife1 DrugsEcstaLife1;
run;

proc factor data=YRBS2011
	method=prinit 
	priors=max 
	scree 
	residuals 
	rotate=promax
	corr 
	heywood 
	plots=(scree initloadings preloadings loadings);
	var DrugsMarLife1 DrugsMarDay2 DrugsComboLife1
		DrugsMarDaySP3 DrugsCocaLife1 DrugsCocaDay2 DrugsInhaLife1
		DrugsHeroLife1 DrugsMethLife1 DrugsSteroLife1 DrugsInjectLife1 DrugsEcstaLife1;
run;

proc corr data=YRBS2011 nocorr alpha nomiss;
	var SexForce1 SexAge3 SexProtect7;
run;

proc factor data=YRBS2011
	method=prinit 
	priors=smc 
	scree 
	residuals 
	rotate=promax
	corr 
	heywood 
	plots=(scree initloadings preloadings loadings);
	var SexForce1 SexAge3 SexProtect7;
run;

proc corr data=YRBS2011 nocorr alpha nomiss;
	var SexForce1 SexNumLife4 SexProtect7;
run;

proc factor data=YRBS2011
	method=prinit 
	priors=smc 
	scree 
	residuals 
	rotate=promax
	corr 
	heywood 
	plots=(scree initloadings preloadings loadings);
	var SexForce1 SexNumLife4 SexProtect7;
run;

proc corr data=YRBS2011 nocorr alpha nomiss;
	var SexForce1 SexNumMonth4 SexSub5  SexProtect7;
run;

proc factor data=YRBS2011
	method=prinit 
	priors=smc 
	scree 
	residuals 
	rotate=promax
	corr 
	heywood 
	plots=(scree initloadings preloadings loadings);
	var SexForce1 SexNumMonth4 SexSub5 SexProtect7;
run;

proc corr data=YRBS2011 nocorr alpha nomiss;
	var TobacDaily2 TobacQuit3 TobacDaysSP4 TobacAmount5
		TobacChew7 TobacChewSP8 TobacCigar9;
run;

proc factor data=YRBS2011
	method=prinit 
	priors=max 
	scree 
	residuals 
	rotate=promax
	corr 
	heywood 
	plots=(scree initloadings preloadings loadings);
	var TobacDaily2 TobacQuit3 TobacDaysSP4 TobacAmount5
		TobacChew7 TobacChewSP8 TobacCigar9;
run;

proc corr data=YRBS2011 nocorr alpha nomiss;
	var TobacDaily2 TobacQuit3 TobacDays4 TobacDaysSP4 
		TobacChew7 TobacChewSP8 TobacCigar9;
run;

proc factor data=YRBS2011
	method=prinit 
	priors=max 
	scree 
	residuals 
	rotate=promax
	corr 
	heywood 
	plots=(scree initloadings preloadings loadings);
	var TobacDaily2 TobacQuit3 TobacDays4 TobacDaysSP4 
		TobacChew7 TobacChewSP8 TobacCigar9;
run;

proc corr data=YRBS2011 nocorr alpha nomiss;
	var VehicleOtherD3 VehicleSelfD3 ;
run;

proc factor data=YRBS2011
	method=prinit 
	priors=smc 
	scree 
	residuals 
	rotate=promax
	maxiter=100
	corr 
	heywood 
	plots=(scree initloadings preloadings loadings);
	var VehicleOtherD3 VehicleSelfD3 ;
run;


proc corr data=YRBS2011 nocorr alpha nomiss;
	var ViolMultWeap1 ViolMultWeapSP1 ViolGun1 ViolUnsafe2 ViolThreatSP2 ViolDamageSP2 ViolFight3 
		ViolFightSP3 ViolInjury3 ViolSigOth4;
run;

proc factor data=YRBS2011
	method=prinit 
	priors=max 
	scree 
	residuals 
	rotate=promax
	corr 
	heywood 
	plots=(scree initloadings preloadings loadings);
	var ViolMultWeap1 ViolMultWeapSP1 ViolGun1 ViolUnsafe2 ViolThreatSP2 ViolDamageSP2 ViolFight3 
		ViolFightSP3 ViolInjury3 ViolSigOth4;
run;

proc corr data=YRBS2011 nocorr alpha nomiss;
	var ViolMultWeap1 ViolMultWeapSP1 ViolGun1 ViolUnsafe2 ViolThreatSP2 ViolDamageSP2 ViolFight3 
		ViolFightSP3 ViolInjury3;
run;

proc factor data=YRBS2011
	method=prinit 
	priors=max 
	scree 
	residuals 
	rotate=promax
	corr 
	heywood 
	plots=(scree initloadings preloadings loadings);
	var ViolMultWeap1 ViolMultWeapSP1 ViolGun1 ViolUnsafe2 ViolThreatSP2 ViolDamageSP2 ViolFight3 
		ViolFightSP3 ViolInjury3;
run;

ods graphics off;