*************************************************************;
/*    SASGF2014_Analysis.sas

Directory:  D:\SASGF_2014
            
Author:  Deanna Naomi Schreiber-Gregory

Created:  February 26th, 2014

Revised:  March 7th, 2014

Purpose/Abstract:  This Program performs a logistic regression
				   analysis of the YRBSS project.

Input data file ----------------------------------------------
	YRBS1991.dat
	YRBS1993.dat
	YRBS1995.dat
	YRBS1997.dat
	YRBS1999.dat
	YRBS2001.dat
	YRBS2003.dat
	YRBS2005.dat
	YRBS2007.dat
	YRBS2009.dat
	YRBS2011.dat

Created Variables --------------------------------------------
   Too Many: concatenated variables based on excel File
   E:\SASGF_2014\Application\Survey Questions.xlsx

Data Source:  CDC
*/
**************************************************************;

/* Tell SAS where to find the data files and formats */

OPTIONS NODATE NONUMBER NOCENTER SKIP=0;
libname mydata 'D:\SUGGF_2014';			/* Tells SAS where the data is */
libname library 'D:\SUGGF_2014';		/* Tells SAS where the formats are */

/* ODS RTF; */
title1 "YRBSS Analysis - SASGF 2014";

/* Format and input data from YRBS 1991 */

data YRBS1991;													/* Create SAS dataset YRBS1991 */
	set mydata.YRBS1991;										/* The SET statement reads data from an existing SAS dataset */
	
	year=1991;
	AlcoholLife1=q33; AlcoholDay2=q34; AlcoholBinge4=q35;														/* Alcohol */
	DemoAge1=q1; DemoSex2=q2; DemoEth3=q4; 																		/* Demotgraphics */
	DrugsMarLife1=q37; DrugsMarDay2=q38; DrugsCocaLife1=q40; DrugsCocaDay2=q41; DrugsSteroLife1=q44; 			/* Drugs */
	DrugsComboLife1=q43;
	EduRank2=q5; ExerHardActive1=q68; ExerStrength4=q70; ExerStretch5=q69; 										/* Exercise */
	MoodConsiderS2=q19; MoodPlanS3=Q20; MoodAttemptS4=q21; MoodSeriousS5=q22;									/* Mood */
	SexHist2=q48; SexAge3=q49; SexNumLife4=q50; SexNumMonth4=q51; SexSub5=q52; SexProtect7=q54; 				/* Sexuality */
	SexPregnant8=q55; SexSTD9=q56;		
	TobacTry1=q23; TobacDaily2=q26; TobacDays4=q28; TobacAmount5=q29; 											/* Tobacco */
	VehicleHelmet1=q8; VehicleSelfSB2=q6; VehicleOtherD3=q11; VehicleSelfD3=q12;								/* Vehicle */
	ViolMultWeap1=q14; ViolFight3=q16; ViolInjury3=q18; ViolWhom4=q17;											/* Violence */
	WeightThink1=q57; WeightTry1=q58;																			/* Weight */

	if q59=1 or q59=5 then WeightDietExer2='2';																	/* Adjusted */
	else if q59=2 or q59=3 or q59=4 then WeightDietExer2='1';
	else WeightDietExer2=' ';

	if q60=1 or q60=5 then WeightPurge2='2';
	else if q60=2 or q60=3 or q60=4 then WeightPurge2='1';
	else WeightPurge2=' ';

	if q31=1 then TobacChew7='2';
	else if q31=2 or q31=3 or q31=4 then TobacChew7='1';
	else TobacChew7=' ';

	if q30=2 then TobacQuit3='1';
	else if q30=3 then TobacQuit3='2';
	else TobacQuit3=' ';

	if q74=1 and q75=1 then ExerTeam6='1';
	else if (q74=1 and q75=2) or (q74=2 and q75=1) then ExerTeam6='2';
	else if (q74=1 and q75=3) or (q74=3 and q75=1) or (q74=2 and q75=2) then ExerTeam6='3';
	else if (q74=2 and q75=3) or (q74=3 and q75=2) or (q74=3 and q75=3) or q74=4 or q75=4 then ExerTeam6='4';
	else ExerTeam6=' ';

	drop q1-q98 qn1-qn98 qnfrcig qnfrvg qnrovwgt qnovwgt qndlype qnanytob qnminpa qnnopa qnasatck bmipct ethorig raceorig qndepo
		 qndepopl qndual qnfrvg2 qnfruit qnveg qnpa0day qnpa7day qnowt qnobese metrost qnstore qnabstsx qnrespsx qntencig
		 q4orig;

run;

/* Format and input data from YRBS 1993 */

data YRBS1993;													/* Create SAS dataset YRBS1993 */
	set mydata.YRBS1993;										/* The SET statement reads data from an existing SAS dataset */

	year=1993;
	AlcoholLife1=q39; AlcoholDay2=q40; AlcoholBinge4=q41; 														/* Alcohol */
	DemoAge1=q1; DemoSex2=q2; DemoEth3=q4;																		/* Demographics */
	DrugsMarLife1=q44; DrugsMarDay2=q45; DrugsMarDaySP3=q46; DrugsCocaLife1=q48; DrugsCocaDay2=q49; 			/* Drugs */
	DrugsSteroLife1=q52; DrugsInjectLife1=q53; DrugsComboLife1=q51;									
	EduRank2=q5; EduMom4=q86; EduDad5=q87;																		/* Education */
	ExerHardActive1=q77; ExerStrength4=q79; ExerStretch5=q78; 													/* Exercise */
	MoodConsiderS2=q24; MoodPlanS3=q25; MoodAttemptS4=q26; MoodSeriousS5=q27;									/* Mood */
	SexHist2=q57; SexAge3=q58; SexNumLife4=q59; SexNumMonth4=q60; SexSub5=q61; SexProtect7=q63; 				/* Sexuality */
	SexPregnant8=q64; SexSTD9=q65;
	TobacTry1=q28; TobacDaily2=q30; TobacDays4=q32; TobacDaysSP4=q34; TobacAmount5=q33; 						/* Tobacco */
	VehicleHelmet1=q8; VehicleSelfSB2=q6; VehicleOtherD3=q11; VehicleSelfD3=q12;								/* Vehicle */
	ViolMultWeap1=q13; ViolMultWeapSP1=q15; ViolGun1=q14; ViolUnsafe2=q16; ViolThreatSP2=q17; 					/* Violence */
	ViolDamageSP2=q18; ViolFight3=q19; ViolFightSP3=q22; ViolInjury3=q21; ViolWhom4=q20;
	WeightThink1=q66; WeightTry1=q67;																			/* Weight */

	if q68=1 or q68=5 then WeightDietExer2='2';																	/* Adjusted */
	else if q68=2 or q68=3 or q68=4 then WeightDietExer2='1';
	else WeightDietExer2=' ';

	if q69=1 or q69=5 then WeightPurge2='2';
	else if q69=2 or q69=3 or q69=4 then WeightPurge2='1';
	else WeightPurge2=' ';

	if q37=1 then TobacChewSP8='2';
	else if q37=2 or q37=3 or q37=4 then TobacChewSP8='1';
	else TobacChewSP8=' ';

	if q36=1 then TobacChew7='2';
	else if q36=2 or q36=3 or q36=4 then TobacChew7='1';
	else TobacChew7=' ';

	if q35=2 then TobacQuit3='1';
	else if q35=3 then TobacQuit3='2';
	else TobacQuit3=' ';

	if q83=1 and q84=1 then ExerTeam6='1';
	else if (q83=1 and q84=2) or (q83=2 and q84=1) then ExerTeam6='2';
	else if (q83=1 and q84=3) or (q83=3 and q84=1) or (q83=2 and q84=2) then ExerTeam6='3';
	else if (q83=2 and q84=3) or (q83=3 and q84=2) or (q83=3 and q84=3) or q83=4 or q84=4 then ExerTeam6='4';
	else ExerTeam6=' ';

	if q42=1 then AlcoholDaySP3='1';
	else if q42=2 or q42=3 then AlcoholDaySP3='2';
	else if q42=4 then AlcoholDaySP3='3';
	else if q42=5 then AlcoholDaySP3='4';
	else if q42=6 then AlcoholDaySP3='5';
	else if q42=7 then AlcoholDaySP3='6';

	drop q1-q98 qn1-qn98 qnfrcig qnfrvg qnrovwgt qnovwgt qndlype qnanytob qnminpa qnnopa qnasatck bmipct ethorig raceorig qndepo
		 qndepopl qndual qnfrvg2 qnfruit qnveg qnpa0day qnpa7day qnowt qnobese metrost qnstore qnabstsx qnrespsx qntencig
		 q4orig;

run;

/* Format and input data from YRBS 1995 */

data YRBS1995;													/* Create SAS dataset YRBS1995 */
	set mydata.YRBS1995;										/* The SET statement reads data from an existing SAS dataset */

	year=1995;
	AlcoholLife1=q37; AlcoholDay2=q38; AlcoholBinge4=q39; 														/* Alcohol */
	DemoAge1=q1; DemoSex2=q2; DemoEth3=q4; 																		/* Demographics */
	DrugsMarLife1=q42; DrugsMarDay2=q43; DrugsMarDaySP3=q44; DrugsCocaLife1=q46; 								/* Drugs */
	DrugsCocaDay2=q47; DrugsInhaLife1=q49; DrugsSteroLife1=q50; DrugsComboLife1=q51;
	EduMom4=q87; EduDad5=q88; 																					/* Education */
	ExerHardActive1=q77; ExerSoftActive2=q80; ExerStrength4=q79; ExerStretch5=q78; 								/* Exercise */
	MoodConsiderS2=q22; MoodPlanS3=q23; MoodAttemptS4=q24; MoodSeriousS5=q25;									/* Mood */
	SexHist2=q56; SexAge3=q57; SexNumLife4=q58; SexNumMonth4=q59; SexSub5=q60;									/* Sexuality */
	SexProtect7=q62; SexPregnant8=q63;
	TobacTry1=q26; TobacDaily2=q85; TobacDays4=q28; TobacDaysSP4=q32; TobacAmount5=q29; 						/* Tobacco */
	VehicleHelmet1=q7; VehicleSelfSB2=q5; VehicleOtherD3=q10; VehicleSelfD3=q11;								/* Vehicle */
	ViolMultWeap1=q12; ViolMultWeapSP1=q14; ViolGun1=q13; ViolUnsafe2=q15; ViolThreatSP2=q16;					/* Violence */
	ViolDamageSP2=q17; ViolFight3=q18; ViolFightSP3=q20; ViolInjury3=q19; ViolWhom4=q21;
	WeightThink1=q64; WeightTry1=q65; WeightSupp2=q69; WeightPurge2=q68;										/* Weight */

	if q30=1 then TobacGet6='1';
	else if q30=2 then TobacGet6='2';
	else if q30=3 then TobacGet6='3';
	else if q30=4 then TobacGet6='4';
	else if q30=5 then TobacGet6='5';
	else if q30=6 then TobacGet6='6';
	else if q30=7 then TobacGet6='7';
	else TobacGet6=' ';

	if q67=1 or q66=1 then WeightDietExer2='1';																	/* Adjusted */
	else if q67=2 and q66=2 then WeightDietExer2='2';
	else WeightDietExer2=' ';

	if q35=1 then TobacChewSP8='2';
	else if q35=2 or q35=3 or q35=4 or q35=5 or q35=6 or q35=7 then TobacChewSP8='1';
	else TobacChewSP8=' ';

	if q34=1 then TobacChew7='2';
	else if q34=2 or q34=3 or q34=4 or q34=5 or q34=6 or q34=7 then TobacChew7='1';
	else TobacChew7=' ';

	if q33=2 then TobacQuit3='1';
	else if q33=3 then TobacQuit3='2';
	else TobacQuit3=' ';

	if q83=1 and q84=1 then ExerTeam6='1';
	else if (q83=1 and q84=2) or (q83=2 and q84=1) then ExerTeam6='2';
	else if (q83=1 and q84=3) or (q83=3 and q84=1) or (q83=2 and q84=2) then ExerTeam6='3';
	else if (q83=2 and q84=3) or (q83=3 and q84=2) or (q83=3 and q84=3) or q83=4 or q84=4 then ExerTeam6='4';
	else ExerTeam6=' ';

	if q52=1 then DrugsInjectLife1='2';
	else if q52=2 or q52=3 then DrugsInjectLife1='1';
	else DrugsInjectLife1=' ';

	if q40=1 then AlcoholDaySP3='1';
	else if q40=2 or q40=3 then AlcoholDaySP3='2';
	else if q40=4 then AlcoholDaySP3='3';
	else if q40=5 then AlcoholDaySP3='4';
	else if q40=6 then AlcoholDaySP3='5';
	else if q40=7 then AlcoholDaySP3='6';

	drop q1-q98 qn1-qn98 qnfrcig qnfrvg qnrovwgt qnovwgt qndlype qnanytob qnminpa qnnopa qnasatck bmipct ethorig raceorig qndepo
		 qndepopl qndual qnfrvg2 qnfruit qnveg qnpa0day qnpa7day qnowt qnobese metrost qnstore qnabstsx qnrespsx qntencig
		 q4orig;

run;

/* Format and input data from YRBS 1997 */

data YRBS1997;													/* Create SAS dataset YRBS1997 */
	set mydata.YRBS1997;										/* The SET statement reads data from an existing SAS dataset */

	year=1997;
	AlcoholLife1=q37; AlcoholDay2=q38; AlcoholBinge4=q39; 														/* Alcohol */
	DemoAge1=q1; DemoSex2=q2; DemoEth3=q4; 																		/* Demographics */
	DrugsMarLife1=q42; DrugsMarDay2=q43; DrugsMarDaySP3=q44; DrugsCocaLife1=q46; 								/* Drugs */
	DrugsCocaDay2=q47; DrugsInhaLife1=q49; DrugsSteroLife1=q50; DrugsComboLife1=q51;
	EduMom4=q88; EduDad5=q89;																					/* Education */
	ExerHardActive1=q77; ExerSoftActive2=q80; ExerStrength4=q79; ExerStretch5=q78; 								/* Exercise */
	MoodConsiderS2=q22; MoodPlanS3=q23; MoodAttemptS4=q24; MoodSeriousS5=q25;									/* Mood */
	SexHist2=q56; SexAge3=q57; SexNumLife4=q58; SexNumMonth4=q59; 												/* Sexuality */
	SexSub5=q60; SexProtect7=q62; SexPregnant8=q63;
	TobacTry1=q26; TobacDaily2=q85; TobacDays4=q28; TobacDaysSP4=q32; TobacAmount5=q29;							/* Tobacco */
	VehicleHelmet1=q7; VehicleSelfSB2=q5; VehicleOtherD3=q10; VehicleSelfD3=q11;								/* Vehicle */
	ViolMultWeap1=q12; ViolMultWeapSP1=q14; ViolGun1=q13; ViolUnsafe2=q15;										/* Violence */
	ViolThreatSP2=q16; ViolDamageSP2=q17; ViolFight3=q18; ViolFightSP3=q20;
	ViolInjury3=q19;
	WeightThink1=q64; WeightTry1=q65; WeightSupp2=q69; WeightPurge2=q68;										/* Weight */

	if q30=1 then TobacGet6='1';
	else if q30=2 then TobacGet6='2';
	else if q30=3 then TobacGet6='3';
	else if q30=4 then TobacGet6='4';
	else if q30=5 then TobacGet6='5';
	else if q30=6 then TobacGet6='6';
	else if q30=7 then TobacGet6='7';
	else TobacGet6=' ';

	if q67=1 or q66=1 then WeightDietExer2='1';																	/* Adjusted */
	else if q67=2 and q66=2 then WeightDietExer2='2';
	else WeightDietExer2=' ';

	if q86=1 then TobacCigar9='2';
	else if q86=2 or q86=3 or q86=4 or q86=5 or q86=6 or q86=7 then TobacCigar9='1';
	else TobacCigar9=' ';

	if q35=1 then TobacChewSP8='2';
	else if q35=2 or q35=3 or q35=4 or q35=5 or q35=6 or q35=7 then TobacChewSP8='1';
	else TobacChewSP8=' ';

	if q34=1 then TobacChew7='2';
	else if q34=2 or q34=3 or q34=4 or q34=5 or q34=6 or q34=7 then TobacChew7='1';
	else TobacChew7=' ';

	if q33=2 then TobacQuit3='1';
	else if q33=3 then TobacQuit3='2';
	else TobacQuit3=' ';

	if q62=2 then SexProtect7='2';
	else if q62=3 or q62=4 or q62=5 or q62=6 then SexProtect7='1';
	else if q62=7 then SexProtect7='3';
	else SexProtect7=' ';

	if q83=1 and q84=1 then ExerTeam6='1';
	else if (q83=1 and q84=2) or (q83=2 and q84=1) then ExerTeam6='2';
	else if (q83=1 and q84=3) or (q83=3 and q84=1) or (q83=2 and q84=2) then ExerTeam6='3';
	else if (q83=2 and q84=3) or (q83=3 and q84=2) or (q83=3 and q84=3) or q83=4 or q84=4 then ExerTeam6='4';
	else ExerTeam6=' ';

	if q52=1 then DrugsInjectLife1='2';
	else if q52=2 or q52=3 then DrugsInjectLife1='1';
	else DrugsInjectLife1=' ';

	if q40=1 then AlcoholDaySP3='1';
	else if q40=2 or q40=3 then AlcoholDaySP3='2';
	else if q40=4 then AlcoholDaySP3='3';
	else if q40=5 then AlcoholDaySP3='4';
	else if q40=6 then AlcoholDaySP3='5';
	else if q40=7 then AlcoholDaySP3='6';

	drop q1-q98 qn1-qn98 qnfrcig qnfrvg qnrovwgt qnovwgt qndlype qnanytob qnminpa qnnopa qnasatck bmipct ethorig raceorig qndepo
		 qndepopl qndual qnfrvg2 qnfruit qnveg qnpa0day qnpa7day qnowt qnobese metrost qnstore qnabstsx qnrespsx qntencig
		 q4orig;

run;

/* Format and input data from YRBS 1999 */

data YRBS1999;													/* Create SAS dataset YRBS1999 */
	set mydata.YRBS1999;										/* The SET statement reads data from an existing SAS dataset */

	year=1999;
	AlcoholLife1=q39; AlcoholDay2=q41; AlcoholBinge4=q42; 															/* Alcohol */
	DemoAge1=q1; DemoSex2=q2; 																						/* Demographics */
	DrugsMarLife1=q44; DrugsMarDay2=q46; DrugsMarDaySP3=q47; DrugsCocaLife1=q48;									/* Drugs */
	DrugsCocaDay2=q49; DrugsInhaLife1=q50; DrugsInhaDay2=q51; DrugsHeroLife1=q52;
	DrugsMethLife1=q53; DrugsSteroLife1=q54;
	ExerHardActive1=q79; ExerSoftActive1=q80; ExerStrength4=q81; ExerTeam6=q85; 									/* Exercise */
	HealthDoctor1=q89; HealthDentist2=q91; 																			/* Health */
	MoodDep1=q22; MoodConsiderS2=q23; MoodPlanS3=q24; MoodAttemptS4=q25; MoodSeriousS5=q26;							/* Mood */
	SexForce1=q21; SexHist2=q57; SexAge3=q58; SexNumLife4=q59; SexNumMonth4=q60; SexSub5=q61;						/* Sexuality */
	SexPregnant8=q64; 
	TobacTry1=q27; TobacDaily2=q34; TobacDays4=q29; TobacDaysSP4=q33; TobacAmount5=q30;								/* Tobacco */
	TobacQuit3=q35;
	VehicleHelmet1=q7; VehicleSelfSB2=q9; VehicleOtherD3=q10; VehicleSelfD3=q11;									/* Vehicle */
	ViolMultWeap1=q12; ViolMultWeapSP1=q14; ViolGun1=q13; ViolUnsafe2=q15; ViolThreatSP2=q16;						/* Violence */
	ViolFight3=q17; ViolFightSP3=q19; ViolInjury3=q18; ViolSigOth4=q20;
	WeightThink1=q65; WeightTry1=q66; WeightFast2=q69; WeightSupp2=q70; WeightPurge2=q71;							/* Weight */

	if q31=1 then TobacGet6='1';
	else if q31=2 then TobacGet6='2';
	else if q31=3 then TobacGet6='3';
	else if q31=4 then TobacGet6='4';
	else if q31=5 then TobacGet6='5';
	else if q31=6 then TobacGet6='6';
	else if q31=7 then TobacGet6='7';
	else TobacGet6=' ';

	if q67=1 or q68=1 then WeightDietExer2='1';																		/* Adjusted */
	else if q67=2 and q68=2 then WeightDietExer2='2';
	else WeightDietExer2=' ';

	if q38=1 then TobacCigar9='2';
	else if q38=2 or q38=3 or q38=4 or q38=5 or q38=6 or q38=7 then TobacCigar9='1';
	else TobacCigar9=' ';

	if q37=1 then TobacChewSP8='2';
	else if q37=2 or q37=3 or q37=4 or q37=5 or q37=6 or q37=7 then TobacChewSP8='1';
	else TobacChewSP8=' ';

	if q36=1 then TobacChew7='2';
	else if q36=2 or q36=3 or q36=4 or q36=5 or q36=6 or q36=7 then TobacChew7='1';
	else TobacChew7=' ';

	if q63=2 then SexProtect7='2';
	else if q63=3 or q63=4 or q63=5 or q63=6 or q63=7 then SexProtect7='1';
	else if q63=8 then SexProtect7='3';
	else SexProtect7=' ';

	if q86=1 then ExerInjury7='2';
	else if q86=2 or q86=3 or q86=4 or q86=5 or q86=6 then ExerInjury7='1';
	else ExerInjury7=' ';

	if q55=1 then DrugsInjectLife1='2';
	else if q55=2 or q55=3 then DrugsInjectLife1='1';
	else DrugsInjectLife1=' ';

	if q4=1 then DemoEth3='5';
	else if q4=2 or q4=5 then DemoEth3='4';
	else if q4=3 then DemoEth3='2';
	else if q4=4 then DemoEth3='3';
	else if q4=6 then DemoEth3='1';
	else if q4=7 or q4=8 then DemoEth3='6';
	else DemoEth3=' ';

	if q43=1 then AlcoholDaySP3='1';
	else if q43=2 then AlcoholDaySP3='2';
	else if q43=3 then AlcoholDaySP3='3';
	else if q43=4 then AlcoholDaySP3='4';
	else if q43=5 then AlcoholDaySP3='5';
	else if q43=6 or q43=7 then AlcoholDaySP3='6';

	drop q1-q98 qn1-qn98 qnfrcig qnfrvg qnrovwgt qnovwgt qndlype qnanytob qnminpa qnnopa qnasatck bmipct ethorig raceorig qndepo
		 qndepopl qndual qnfrvg2 qnfruit qnveg qnpa0day qnpa7day qnowt qnobese metrost qnstore qnabstsx qnrespsx qntencig
		 q4orig;

run;

/* Format and input data from YRBS 2001 */

data YRBS2001;													/* Create SAS dataset YRBS2001 */
	set mydata.YRBS2001;										/* The SET statement reads data from an existing SAS dataset */

	year=2001;
	AlcoholLife1=q40; AlcoholDay2=q42; AlcoholBinge4=q43;															/* Alcohol */
	DemoAge1=q1; DemoSex2=q2;																						/* Demographics */
	DrugsMarLife1=q45; DrugsMarDay2=q47; DrugsMarDaySP3=q48; DrugsCocaLife1=q49;									/* Drugs */
	DrugsCocaDay2=q50; DrugsInhaLife1=q51; DrugsInhaDay2=q52; DrugsHeroLife1=q53;
	DrugsMethLife1=q54; DrugsSteroLife1=q55; DrugsEcstaLife1=q90; DrugsComboLife1=q91;
	EduGrades1=q7; 																									/* Education */
	ExerHardActive1=q80; ExerSoftActive1=q81; ExerStrength4=q82; ExerTeam6=q86; 									/* Exercise */
	HealthDoctor1=q93; HealthDentist2=q94; 																			/* Health */
	MoodDep1=q23; MoodConsiderS2=q24; MoodPlanS3=q25; MoodAttemptS4=q26; MoodSeriousS5=q27;							/* Mood */
	SexForce1=q22; SexHist2=q58; SexAge3=q59; SexNumLife4=q60; SexNumMonth4=q61; SexSub5=q62;						/* Sexuality */
	SexPregnant8=q65;				
	TobacTry1=q28; TobacDaily2=q35; TobacDays4=q30; TobacDaysSP4=q34; TobacAmount5=q31;								/* Tobacco */
	VehicleHelmet1=q8; VehicleOtherSB2=q88; VehicleSelfSB2=q10; VehicleOtherD3=q11; 								/* Vehicle */
	VehicleSelfD3=q12;
	ViolMultWeap1=q13; ViolMultWeapSP1=q15; ViolGun1=q14; ViolUnsafe2=q16; ViolThreatSP2=q17;						/* Violence */
	ViolFight3=q18; ViolFightSP3=q20; ViolInjury3=q19; ViolSigOth4=q21;
	WeightThink1=q66; WeightTry1=q67; WeightFast2=q70; WeightSupp2=q71; WeightPurge2=q72;							/* Weight */

	if q32=1 then TobacGet6='1';
	else if q32=2 then TobacGet6='2';
	else if q32=3 then TobacGet6='3';
	else if q32=4 then TobacGet6='4';
	else if q32=5 then TobacGet6='5';
	else if q32=7 then TobacGet6='6';
	else if q32=6 or q32=8 then TobacGet6='7';
	else TobacGet6=' ';

	if q69=1 or q68=1 then WeightDietExer2='1';																		/* Adjusted */
	else if q69=2 and q68=2 then WeightDietExer2='2';
	else WeightDietExer2=' ';

	if q39=1 then TobacCigar9='2';
	else if q39=2 or q39=3 or q39=4 or q39=5 or q39=6 or q39=7 then TobacCigar9='1';
	else TobacCigar9=' ';

	if q38=1 then TobacChewSP8='2';
	else if q38=2 or q38=3 or q38=4 or q38=5 or q38=6 or q38=7 then TobacChewSP8='1';
	else TobacChewSP8=' ';

	if q37=1 then TobacChew7='2';
	else if q37=2 or q37=3 or q37=4 or q37=5 or q37=6 or q37=7 then TobacChew7='1';
	else TobacChew7=' ';

	if q36=2 then TobacQuit3='1';
	else if q36=3 then TobacQuit3='2';
	else TobacQuit3=' ';

	if q64=2 then SexProtect7='2';
	else if q64=3 or q64=4 or q64=5 or q64=6 or q64=7 then SexProtect7='1';
	else if q64=8 then SexProtect7='3';
	else SexProtect7=' ';

	if q92=1 or q92=3 then ExerInjury7='2';
	else if q92=2 then ExerInjury7='1';
	else ExerInjury7=' ';

	if q56=1 then DrugsInjectLife1='2';
	else if q56=2 or q56=3 then DrugsInjectLife1='1';
	else DrugsInjectLife1=' ';

	if q4=1 then DemoEth3='5';
	else if q4=2 or q4=5 then DemoEth3='4';
	else if q4=3 then DemoEth3='2';
	else if q4=4 then DemoEth3='3';
	else if q4=6 then DemoEth3='1';
	else if q4=7 or q4=8 then DemoEth3='6';
	else DemoEth3=' ';

	if q44=1 then AlcoholDaySP3='1';
	else if q44=2 then AlcoholDaySP3='2';
	else if q44=3 then AlcoholDaySP3='3';
	else if q44=4 then AlcoholDaySP3='4';
	else if q44=5 then AlcoholDaySP3='5';
	else if q44=6 or q44=7 then AlcoholDaySP3='6';

	drop q1-q98 qn1-qn98 qnfrcig qnfrvg qnrovwgt qnovwgt qndlype qnanytob qnminpa qnnopa qnasatck bmipct ethorig raceorig qndepo
		 qndepopl qndual qnfrvg2 qnfruit qnveg qnpa0day qnpa7day qnowt qnobese metrost qnstore qnabstsx qnrespsx qntencig
		 q4orig;

run;

/* Format and input data from YRBS 2003 */

data YRBS2003;													/* Create SAS dataset YRBS2003 */
	set mydata.YRBS2003;										/* The SET statement reads data from an existing SAS dataset */

	year=2003;
	AlcoholLife1=q39; AlcoholDay2=q41; AlcoholBinge4=q42;															/* Alcohol */
	DemoAge1=q1; DemoSex2=q2;																						/* Demographics */
	DrugsMarLife1=q44; DrugsMarDay2=q46; DrugsMarDaySP3=q47; DrugsCocaLife1=q48;									/* Drugs */
	DrugsCocaDay2=q49; DrugsInhaLife1=q50; DrugsInhaDay2=q51; DrugsHeroLife1=q52;
	DrugsMethLife1=q53; DrugsSteroLife1=q55; DrugsEcstaLife1=q54; DrugsComboLife1=q91;
	EduGrades1=q7;																									/* Education */
	ExerHardActive1=q80; ExerSoftActive1=q81; ExerStrength4=q82; ExerTeam6=q86;										/* Exercise */
	HealthDentist2=q94; 																							/* Health */
	MoodDep1=q23; MoodConsiderS2=q24; MoodPlanS3=q25; MoodAttemptS4=q26; MoodSeriousS5=q27;							/* Mood */
	SexForce1=q22; SexHist2=q58; SexAge3=q59; SexNumLife4=q60; SexNumMonth4=q61; 									/* Sexuality */
	SexSub5=q62; SexPregnant8=q65; 	
	TobacTry1=q28; TobacDaily2=q34; TobacDays4=q30; TobacDaysSP4=q33; TobacAmount5=q31;								/* Tobacco */
	VehicleOtherSB2=q88; VehicleSelfSB2=q9; VehicleOtherD3=q10; VehicleSelfD3=q11;									/* Vehicle */
	ViolMultWeap1=q12; ViolMultWeapSP1=q14; ViolGun1=q13; ViolUnsafe2=q15; ViolThreatSP2=q16;						/* Violence */
	ViolDamageSP2=q17; ViolFight3=q18; ViolFightSP3=q20; ViolInjury3=q19; ViolSigOth4=q21;
	WeightThink1=q66; WeightTry1=q67; WeightFast2=q70; WeightSupp2=q71; WeightPurge2=q72;							/* Weight */

	if q32=1 then TobacGet6='1';
	else if q32=2 then TobacGet6='2';
	else if q32=3 then TobacGet6='3';
	else if q32=4 then TobacGet6='4';
	else if q32=5 then TobacGet6='5';
	else if q32=7 then TobacGet6='6';
	else if q32=6 or q32=8 then TobacGet6='7';
	else TobacGet6=' ';

	if q69=1 or q68=1 then WeightDietExer2='1';																		/* Adjusted */
	else if q69=2 and q68=2 then WeightDietExer2='2';
	else WeightDietExer2=' ';

	if q38=1 then TobacCigar9='2';
	else if q38=2 or q38=3 or q38=4 or q38=5 or q38=6 or q38=7 then TobacCigar9='1';
	else TobacCigar9=' ';

	if q37=1 then TobacChewSP8='2';
	else if q37=2 or q37=3 or q37=4 or q37=5 or q37=6 or q37=7 then TobacChewSP8='1';
	else TobacChewSP8=' ';

	if q36=1 then TobacChew7='2';
	else if q36=2 or q36=3 or q36=4 or q36=5 or q36=6 or q36=7 then TobacChew7='1';
	else TobacChew7=' ';

	if q35=2 then TobacQuit3='1';
	else if q35=3 then TobacQuit3='2';
	else TobacQuit3=' ';

	if q64=2 then SexProtect7='2';
	else if q64=3 or q64=4 or q64=5 or q64=6 or q64=7 then SexProtect7='1';
	else if q64=8 then SexProtect7='3';
	else SexProtect7=' ';

	if q93=1 or q93=3 then ExerInjury7='2';
	else if q93=2 then ExerInjury7='1';
	else ExerInjury7=' ';

	if q56=1 then DrugsInjectLife1='2';
	else if q56=2 or q56=3 then DrugsInjectLife1='1';
	else DrugsInjectLife1=' ';

	if q4=1 then DemoEth3='5';
	else if q4=2 or q4=5 then DemoEth3='4';
	else if q4=3 then DemoEth3='2';
	else if q4=4 then DemoEth3='3';
	else if q4=6 then DemoEth3='1';
	else if q4=7 or q4=8 then DemoEth3='6';
	else DemoEth3=' ';

	if q43=1 then AlcoholDaySP3='1';
	else if q43=2 then AlcoholDaySP3='2';
	else if q43=3 then AlcoholDaySP3='3';
	else if q43=4 then AlcoholDaySP3='4';
	else if q43=5 then AlcoholDaySP3='5';
	else if q43=6 or q43=7 then AlcoholDaySP3='6';

	drop q1-q98 qn1-qn98 qnfrcig qnfrvg qnrovwgt qnovwgt qndlype qnanytob qnminpa qnnopa qnasatck bmipct ethorig raceorig qndepo
		 qndepopl qndual qnfrvg2 qnfruit qnveg qnpa0day qnpa7day qnowt qnobese metrost qnstore qnabstsx qnrespsx qntencig
		 q4orig;

run;

/* Format and input data from YRBS 2005 */

data YRBS2005;													/* Create SAS dataset YRBS2005 */
	set mydata.YRBS2005;										/* The SET statement reads data from an existing SAS dataset */

	year=2005;
	AlcoholLife1=q39; AlcoholDay2=q41; AlcoholBinge4=q42;															/* Alcohol */
	DemoAge1=q1; DemoSex2=q2;																						/* Demographics */
	DrugsMarLife1=q44; DrugsMarDay2=q46; DrugsMarDaySP3=q47; DrugsCocaLife1=q48;									/* Drugs */
	DrugsCocaDay2=q49; DrugsInhaLife1=q50; DrugsHeroLife1=q51;
	DrugsMethLife1=q52; DrugsSteroLife1=q54; DrugsEcstaLife1=q53; DrugsComboLife1=q90;
	EduMiss3=q97;																									/* Education */
	ExerHardActive1=q78; ExerHardActive2=q80; ExerSoftActive1=q79; ExerTeam6=q84;									/* Exercise */
	HealthGeneral3=q7; 																								/* Health */
	MoodDep1=q23; MoodConsiderS2=q24; MoodPlanS3=q25; MoodAttemptS4=q26; MoodSeriousS5=q27;							/* Mood */
	SexForce1=q22; SexHist2=q57; SexAge3=q58; SexNumLife4=q59; SexNumMonth4=q60; 									/* Sexuality */
	SexSub5=q61; 	
	TobacTry1=q28; TobacDaily2=q34; TobacDays4=q30; TobacDaysSP4=q33; TobacAmount5=q31;								/* Tobacco */
	VehicleHelmet1=q88; VehicleSelfSB2=q9; VehicleOtherD3=q10; VehicleSelfD3=q11;									/* Vehicle */
	ViolMultWeap1=q12; ViolMultWeapSP1=q14; ViolGun1=q13; ViolUnsafe2=q15; ViolThreatSP2=q16;						/* Violence */
	ViolDamageSP2=q17; ViolFight3=q18; ViolFightSP3=q20; ViolInjury3=q19; ViolSigOth4=q21;
	WeightThink1=q64; WeightTry1=q65; WeightFast2=q68; WeightSupp2=q69; WeightPurge2=q70;							/* Weight */

	if q32=1 then TobacGet6='1';
	else if q32=2 then TobacGet6='2';
	else if q32=3 then TobacGet6='3';
	else if q32=4 then TobacGet6='4';
	else if q32=5 then TobacGet6='5';
	else if q32=7 then TobacGet6='6';
	else if q32=6 or q32=8 then TobacGet6='7';
	else TobacGet6=' ';

	if q66=1 or q67=1 then WeightDietExer2='1';																		/* Adjusted */
	else if q66=2 and q67=2 then WeightDietExer2='2';
	else WeightDietExer2=' ';

	if q38=1 then TobacCigar9='2';
	else if q38=2 or q38=3 or q38=4 or q38=5 or q38=6 or q38=7 then TobacCigar9='1';
	else TobacCigar9=' ';

	if q37=1 then TobacChewSP8='2';
	else if q37=2 or q37=3 or q37=4 or q37=5 or q37=6 or q37=7 then TobacChewSP8='1';
	else TobacChewSP8=' ';

	if q36=1 then TobacChew7='2';
	else if q36=2 or q36=3 or q36=4 or q36=5 or q36=6 or q36=7 then TobacChew7='1';
	else TobacChew7=' ';

	if q35=2 then TobacQuit3='1';
	else if q35=3 then TobacQuit3='2';
	else TobacQuit3=' ';

	if q63=2 then SexProtect7='2';
	else if q63=3 or q63=4 or q63=5 or q63=6 or q63=7 then SexProtect7='1';
	else if q63=8 then SexProtect7='3';
	else SexProtect7=' ';

	if q92=1 or q92=3 then ExerInjury7='2';
	else if q92=2 then ExerInjury7='1';
	else ExerInjury7=' ';

	if q55=1 then DrugsInjectLife1='2';
	else if q55=2 or q55=3 then DrugsInjectLife1='1';
	else DrugsInjectLife1=' ';

	if q4=1 then DemoEth3='5';
	else if q4=2 or q4=5 then DemoEth3='4';
	else if q4=3 then DemoEth3='2';
	else if q4=4 then DemoEth3='3';
	else if q4=6 then DemoEth3='1';
	else if q4=7 or q4=8 then DemoEth3='6';
	else DemoEth3=' ';

	if q43=1 then AlcoholDaySP3='1';
	else if q43=2 then AlcoholDaySP3='2';
	else if q43=3 then AlcoholDaySP3='3';
	else if q43=4 then AlcoholDaySP3='4';
	else if q43=5 then AlcoholDaySP3='5';
	else if q43=6 or q43=7 then AlcoholDaySP3='6';

	drop q1-q98 qn1-qn98 qnfrcig qnfrvg qnrovwgt qnovwgt qndlype qnanytob qnminpa qnnopa qnasatck bmipct ethorig raceorig qndepo
		 qndepopl qndual qnfrvg2 qnfruit qnveg qnpa0day qnpa7day qnowt qnobese metrost qnstore qnabstsx qnrespsx qntencig
		 q4orig;

run;

/* Format and input data from YRBS 2007 */

data YRBS2007;													/* Create SAS dataset YRBS2007 */
	set mydata.YRBS2007;										/* The SET statement reads data from an existing SAS dataset */

	year=2007;
	AlcoholLife1=q39; AlcoholDay2=q41; AlcoholBinge4=q42; AlcoholGet5=q43;											/* Alcohol */
	DemoAge1=q1; DemoSex2=q2; 																						/* Demographics */
	DrugsMarLife1=q45; DrugsMarDay2=q47; DrugsMarDaySP3=q48; DrugsCocaLife1=q49;									/* Drugs */
	DrugsCocaDay2=q50; DrugsInhaLife1=q51; DrugsHeroLife1=q52; DrugsMethLife1=q53; 
	DrugsSteroLife1=q55; DrugsEcstaLife1=q54; DrugsComboLife1=q89;
	ExerHardActive1=q90; ExerHardActive2=q80; ExerSoftActive1=q91; ExerTeam6=q84;									/* Exercise */
	Sleep1=q97; HealthGeneral3=q98;																					/* Health */
	MoodDep1=q23; MoodConsiderS2=q24; MoodPlanS3=q25; MoodAttemptS4=q26; MoodSeriousS5=q27;							/* Mood */
	SexForce1=q22; SexHist2=q58; SexAge3=q59; SexNumLife4=q60; SexNumMonth4=q61; SexSub5=q62;						/* Sexuality */
	TobacTry1=q28; TobacDaily2=q34; TobacDays4=q30; TobacDaysSP4=q33; TobacAmount5=q31;								/* Tobacco */
	VehicleHelmet1=q88; VehicleSelfSB2=q9; VehicleOtherD3=q10; VehicleSelfD3=q11;									/* Vehicle */
	ViolMultWeap1=q12; ViolMultWeapSP1=q14; ViolGun1=q13; ViolUnsafe2=q15; ViolThreatSP2=q16;						/* Violence */
	ViolDamageSP2=q17; ViolFight3=q18; ViolFightSP3=q20; ViolInjury3=q19; ViolSigOth4=q21;
	WeightThink1=q65; WeightTry1=q66; WeightFast2=q69; WeightSupp2=q70; WeightPurge2=q71;							/* Weight */
	
	if q32=1 then TobacGet6='1';
	else if q32=2 then TobacGet6='2';
	else if q32=3 then TobacGet6='3';
	else if q32=4 then TobacGet6='4';
	else if q32=5 then TobacGet6='5';
	else if q32=7 then TobacGet6='6';
	else if q32=6 or q32=8 then TobacGet6='7';
	else TobacGet6=' ';

	if q67=1 or q68=1 then WeightDietExer2='1';																		/* Adjusted */
	else if q67=2 and q68=2 then WeightDietExer2='2';
	else WeightDietExer2=' ';

	if q38=1 then TobacCigar9='2';
	else if q38=2 or q38=3 or q38=4 or q38=5 or q38=6 or q38=7 then TobacCigar9='1';
	else TobacCigar9=' ';

	if q37=1 then TobacChewSP8='2';
	else if q37=2 or q37=3 or q37=4 or q37=5 or q37=6 or q37=7 then TobacChewSP8='1';
	else TobacChewSP8=' ';

	if q36=1 then TobacChew7='2';
	else if q36=2 or q36=3 or q36=4 or q36=5 or q36=6 or q36=7 then TobacChew7='1';
	else TobacChew7=' ';

	if q35=2 then TobacQuit3='1';
	else if q35=3 then TobacQuit3='2';
	else TobacQuit3=' ';

	if q64=2 then SexProtect7='2';
	else if q64=3 or q64=4 or q64=5 or q64=6 or q64=7 then SexProtect7='1';
	else if q64=8 then SexProtect7='3';
	else SexProtect7=' ';

	if q93=1 or q93=3 then ExerInjury7='2';
	else if q93=2 then ExerInjury7='1';
	else ExerInjury7=' ';

	if q56=1 then DrugsInjectLife1='2';
	else if q56=2 or q56=3 then DrugsInjectLife1='1';
	else DrugsInjectLife1=' ';

	if q4=1 then DemoEth3='3';
	else if q5='A' then DemoEth3='5';
	else if q5='B' or q5='D' then DemoEth3='4';
	else if q5='C' then DemoEth3='2';
	else if q5='E' then DemoEth3='1';
	else DemoEth3='6';

	if q44=1 then AlcoholDaySP3='1';
	else if q44=2 then AlcoholDaySP3='2';
	else if q44=3 then AlcoholDaySP3='3';
	else if q44=4 then AlcoholDaySP3='4';
	else if q44=5 then AlcoholDaySP3='5';
	else if q44=6 or q44=7 then AlcoholDaySP3='6';

	drop q1-q98 qn1-qn98 qnfrcig qnfrvg qnrovwgt qnovwgt qndlype qnanytob qnminpa qnnopa qnasatck bmipct ethorig raceorig qndepo
		 qndepopl qndual qnfrvg2 qnfruit qnveg qnpa0day qnpa7day qnowt qnobese raceeth metrost qnstore qnabstsx qnrespsx qntencig
		 q4orig;

run;

/* Format and input data from YRBS 2009 */

data YRBS2009;													/* Create SAS dataset YRBS2009 */
	set mydata.YRBS2009;										/* The SET statement reads data from an existing SAS dataset */

	year=2009;
	AlcoholLife1=q39; AlcoholDay2=q41; AlcoholBinge4=q42; AlcoholGet5=q43;											/* Alcohol */
	DemoAge1=q1; DemoSex2=q2; 																						/* Demographics */
	DrugsMarLife1=q45; DrugsMarDay2=q47; DrugsMarDaySP3=q48; DrugsCocaLife1=q49;									/* Drugs */
	DrugsCocaDay2=q50; DrugsInhaLife1=q51; DrugsHeroLife1=q52; DrugsMethLife1=q53; 
	DrugsSteroLife1=q55; DrugsEcstaLife1=q54; DrugsPrescLife1=q90; DrugsComboLife1=q89;
	EduGrades1=q98;																									/* Education */
	ExerHardActive1=q91; ExerHardActive2=q80; ExerSoftActive1=q92; ExerTeam6=q84;									/* Exercise */
	Sleep1=q97;																			/* Health */
	MoodDep1=q23; MoodConsiderS2=q24; MoodPlanS3=q25; MoodAttemptS4=q26; MoodSeriousS5=q27;							/* Mood */
	SexForce1=q21; SexHist2=q58; SexAge3=q59; SexNumLife4=q60; SexNumMonth4=q61; SexSub5=q62;						/* Sexuality */
	TobacTry1=q28; TobacDaily2=q34; TobacDays4=q30; TobacDaysSP4=q33; TobacAmount5=q31;								/* Tobacco */
	VehicleHelmet1=q88; VehicleSelfSB2=q9; VehicleOtherD3=q10; VehicleSelfD3=q11;									/* Vehicle */
	ViolMultWeap1=q12; ViolMultWeapSP1=q14; ViolGun1=q13; ViolUnsafe2=q15; ViolThreatSP2=q16;						/* Violence */
	ViolFight3=q17; ViolFightSP3=q19; ViolInjury3=q18; ViolSigOth4=q20; ViolBullySP5=q22;
	WeightThink1=q65; WeightTry1=q66; WeightFast2=q69; WeightSupp2=q70; WeightPurge2=q71;							/* Weight */
	
	if q32=1 then TobacGet6='1';
	else if q32=2 then TobacGet6='2';
	else if q32=3 then TobacGet6='3';
	else if q32=4 then TobacGet6='4';
	else if q32=5 then TobacGet6='5';
	else if q32=7 then TobacGet6='6';
	else if q32=6 or q32=8 then TobacGet6='7';
	else TobacGet6=' ';

	if q67=1 or q68=1 then WeightDietExer2='1';																		/* Adjusted */
	else if q67=2 and q68=2 then WeightDietExer2='2';
	else WeightDietExer2=' ';

	if q38=1 then TobacCigar9='2';
	else if q38=2 or q38=3 or q38=4 or q38=5 or q38=6 or q38=7 then TobacCigar9='1';
	else TobacCigar9=' ';

	if q37=1 then TobacChewSP8='2';
	else if q37=2 or q37=3 or q37=4 or q37=5 or q37=6 or q37=7 then TobacChewSP8='1';
	else TobacChewSP8=' ';

	if q36=1 then TobacChew7='2';
	else if q36=2 or q36=3 or q36=4 or q36=5 or q36=6 or q36=7 then TobacChew7='1';
	else TobacChew7=' ';

	if q35=2 then TobacQuit3='1';
	else if q35=3 then TobacQuit3='2';
	else TobacQuit3=' ';

	if q64=2 then SexProtect7='2';
	else if q64=3 or q64=4 or q64=5 or q64=6 or q64=7 then SexProtect7='1';
	else if q64=8 then SexProtect7='3';
	else SexProtect7=' ';

	if q56=1 then DrugsInjectLife1='2';
	else if q56=2 or q56=3 then DrugsInjectLife1='1';
	else DrugsInjectLife1=' ';

	if q4=1 then DemoEth3='3';
	else if q5='A' then DemoEth3='5';
	else if q5='B' or q5='D' then DemoEth3='4';
	else if q5='C' then DemoEth3='2';
	else if q5='E' then DemoEth3='1';
	else DemoEth3='6';

	if q44=1 then AlcoholDaySP3='1';
	else if q44=2 then AlcoholDaySP3='2';
	else if q44=3 then AlcoholDaySP3='3';
	else if q44=4 then AlcoholDaySP3='4';
	else if q44=5 then AlcoholDaySP3='5';
	else if q44=6 or q44=7 then AlcoholDaySP3='6';

	drop q1-q98 qn1-qn98 qnfrcig qnfrvg qnrovwgt qnovwgt qndlype qnanytob qnminpa qnnopa qnasatck bmipct ethorig raceorig qndepo
		 qndepopl qndual qnfrvg2 qnfruit qnveg qnpa0day qnpa7day qnowt qnobese raceeth metrost qnstore qnabstsx qnrespsx qntencig
		 q4orig;

run;

/* Format and input data from YRBS 2011 */

data YRBS2011;													/* Create SAS dataset YRBS2011 */
	set mydata.YRBS2011;										/* The SET statement reads data from an existing SAS dataset */

	year=2011;
	AlcoholLife1=q40; AlcoholDay2=q42; AlcoholBinge4=q43; AlcoholGet5=q44;											/* Alcohol */
	DemoAge1=q1; DemoSex2=q2; 																						/* Demographics */
	DrugsMarLife1=q46; DrugsMarDay2=q48; DrugsMarDaySP3=q49; DrugsCocaLife1=q50;									/* Drugs */
	DrugsCocaDay2=q51; DrugsInhaLife1=q52; DrugsHeroLife1=q53; DrugsMethLife1=q54; 
	DrugsSteroLife1=q56; DrugsEcstaLife1=q55; DrugsPrescLife1=q57; DrugsComboLife1=q89;																								/* Education */
	ExerHardActive2=q79; ExerStrength4=q92; ExerTeam6=q83;															/* Exercise */
	Sleep1=q96;																										/* Health */
	MoodDep1=q24; MoodConsiderS2=q25; MoodPlanS3=q26; MoodAttemptS4=q27; MoodSeriousS5=q28;							/* Mood */
	SexForce1=q21; SexHist2=q60; SexAge3=q61; SexNumLife4=q62; SexNumMonth4=q63; SexSub5=q64;						/* Sexuality */
	TobacTry1=q29; TobacDaily2=q35; TobacDays4=q31; TobacDaysSP4=q34; TobacAmount5=q32;								/* Tobacco */
	VehicleSelfSB2=q9; VehicleOtherD3=q10; VehicleSelfD3=q11;														/* Vehicle */
	ViolMultWeap1=q12; ViolMultWeapSP1=q14; ViolGun1=q13; ViolUnsafe2=q15; ViolThreatSP2=q16;						/* Violence */
	ViolFight3=q17; ViolFightSP3=q19; ViolInjury3=q18; ViolSigOth4=q20; ViolBullySP5=q22;
	ViolDamageSP2=q88; ViolBullyElec5=q23;
	WeightThink1=q67; WeightTry1=q68; WeightFast2=q69; WeightSupp2=q70; WeightPurge2=q71;							/* Weight */

	if q33=1 then TobacGet6='1';
	else if q33=2 then TobacGet6='2';
	else if q33=3 then TobacGet6='3';
	else if q33=4 then TobacGet6='4';
	else if q33=5 then TobacGet6='5';
	else if q33=7 then TobacGet6='6';
	else if q33=6 or q33=8 then TobacGet6='7';
	else TobacGet6=' ';

	if q39=1 then TobacCigar9='2';
	else if q39=2 or q39=3 or q39=4 or q39=5 or q39=6 or q39=7 then TobacCigar9='1';
	else TobacCigar9=' ';

	if q38=1 then TobacChewSP8='2';
	else if q38=2 or q38=3 or q38=4 or q38=5 or q38=6 or q38=7 then TobacChewSP8='1';
	else TobacChewSP8=' ';

	if q37=1 then TobacChew7='2';
	else if q37=2 or q37=3 or q37=4 or q37=5 or q37=6 or q37=7 then TobacChew7='1';
	else TobacChew7=' ';

	if q36=2 then TobacQuit3='1';
	else if q36=3 then TobacQuit3='2';
	else TobacQuit3=' ';

	if q66=2 then SexProtect7='2';
	else if q66=3 or q66=4 or q66=5 or q66=6 or q66=7 then SexProtect7='1';
	else if q66=8 then SexProtect7='3';
	else SexProtect7=' ';

	if q58=1 then DrugsInjectLife1='2';
	else if q58=2 or q58=3 then DrugsInjectLife1='1';
	else DrugsInjectLife1=' ';

	if q4=1 then DemoEth3='3';
	else if q5='A' then DemoEth3='5';
	else if q5='B' or q5='D' then DemoEth3='4';
	else if q5='C' then DemoEth3='2';
	else if q5='E' then DemoEth3='1';
	else DemoEth3='6';

	if q45=1 then AlcoholDaySP3='1';
	else if q45=2 then AlcoholDaySP3='2';
	else if q45=3 then AlcoholDaySP3='3';
	else if q45=4 then AlcoholDaySP3='4';
	else if q45=5 then AlcoholDaySP3='5';
	else if q45=6 or q45=7 then AlcoholDaySP3='6';

	drop q1-q98 qn1-qn98 qnfrcig qnfrvg qnrovwgt qnovwgt qndlype qnanytob qnminpa qnnopa qnasatck bmipct ethorig raceorig qndepo
		 qndepopl qndual qnfrvg2 qnfruit qnveg qnpa0day qnpa7day qnowt qnobese raceeth metrost qnstore qnabstsx qnrespsx qntencig
		 q4orig;

run;

data YRBS_Total;
	set	YRBS1991	YRBS1993	YRBS1995	YRBS1997	YRBS1999	
		YRBS2001	YRBS2003	YRBS2005	YRBS2007	YRBS2009	YRBS2011;

run;

proc means data=YRBS_Total;
run;

proc surveyfreq data=YRBS_Total;
	strata stratum;
	weight weight;
run;


